/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { AttachmentSortOrder } from "../definitions/AttachmentSortOrder";
import { AttachmentBulkAsResponse } from "../definitions/AttachmentBulkAsResponse";
import { MultiEntityLinksAsResponse } from "../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { AttachmentSingleAsResponse } from "../definitions/AttachmentSingleAsResponse";
export interface GetAttachmentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Used to sort the result by a particular field.
     */
    sort?: AttachmentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Filter the results to attachments based on their status. By default, `current` and `archived` are used.
     */
    status?: Array<"current" | "archived" | "trashed">;
    /**
     * Filters on the mediaType of attachments. Only one may be specified.
     */
    mediaType?: string;
    /**
     * Filters on the file-name of attachments. Only one may be specified.
     */
    filename?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetAttachmentsResponseOKType = {
    results?: Array<AttachmentBulkAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetAttachmentsResponseOK extends GetAttachmentsResponseOKType {
}
export declare type GetAttachmentsResponseError = undefined;
export interface GetAttachmentByIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment to be returned. If you don't know the attachment's ID, use Get attachments for page/blogpost/custom content.
     */
    id: string;
    /**
     * Allows you to retrieve a previously published version. Specify the previous version's number to retrieve its details.
     */
    version?: number;
    /**
  * Includes labels associated with this attachment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-labels"?: boolean;
    /**
  * Includes operations associated with this attachment in the response, as defined in the `Operation` object.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
    /**
  * Includes operations associated with this attachment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes versions associated with this attachment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-versions"?: boolean;
    /**
  * Includes the current version associated with this attachment in the response.
  By default this is included and can be omitted by setting the value to `false`.
  */
    "include-version"?: boolean;
    /**
     * Includes collaborators on the attachment.
     */
    "include-collaborators"?: boolean;
}
export declare type GetAttachmentByIdsResponseOK = AttachmentSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type GetAttachmentByIdsResponseError = undefined;
export interface DeleteAttachmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment to be deleted.
     */
    id: string;
    /**
     * If attempting to purge the attachment.
     */
    purge?: boolean;
}
export declare type DeleteAttachmentResponseOK = undefined;
export declare type DeleteAttachmentResponseError = undefined;
export {};
//# sourceMappingURL=attachment.d.ts.map