/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { AttachmentSortOrder } from "../../definitions/AttachmentSortOrder";
import { AttachmentBulkAsResponse } from "../../definitions/AttachmentBulkAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetAttachmentsForBlogPostRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post for which attachments should be returned.
     */
    id: number | string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: AttachmentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Filter the results to attachments based on their status. By default, `current` and `archived` are used.
     */
    status?: Array<"current" | "archived" | "trashed">;
    /**
     * Filters on the mediaType of attachments. Only one may be specified.
     */
    mediaType?: string;
    /**
     * Filters on the file-name of attachments. Only one may be specified.
     */
    filename?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetAttachmentsForBlogPostResponseOKType = {
    results?: Array<AttachmentBulkAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetAttachmentsForBlogPostResponseOK extends GetAttachmentsForBlogPostResponseOKType {
}
export declare type GetAttachmentsForBlogPostResponseError = undefined;
export {};
//# sourceMappingURL=blogPost.d.ts.map