/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ChildrenResponseAsResponse } from "../definitions/ChildrenResponseAsResponse";
import { MultiEntityLinksAsResponse } from "../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ChildPageAsResponse } from "../definitions/ChildPageAsResponse";
import { ChildCustomContentAsResponse } from "../definitions/ChildCustomContentAsResponse";
export interface GetWhiteboardDirectChildrenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent whiteboard.
     */
    id: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of items per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: string;
}
declare type GetWhiteboardDirectChildrenResponseOKType = {
    results?: Array<ChildrenResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetWhiteboardDirectChildrenResponseOK extends GetWhiteboardDirectChildrenResponseOKType {
}
export declare type GetWhiteboardDirectChildrenResponseError = undefined;
export interface GetDatabaseDirectChildrenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent database.
     */
    id: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of items per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: string;
}
declare type GetDatabaseDirectChildrenResponseOKType = {
    results?: Array<ChildrenResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetDatabaseDirectChildrenResponseOK extends GetDatabaseDirectChildrenResponseOKType {
}
export declare type GetDatabaseDirectChildrenResponseError = undefined;
export interface GetSmartLinkDirectChildrenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent smart link.
     */
    id: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of items per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: string;
}
declare type GetSmartLinkDirectChildrenResponseOKType = {
    results?: Array<ChildrenResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetSmartLinkDirectChildrenResponseOK extends GetSmartLinkDirectChildrenResponseOKType {
}
export declare type GetSmartLinkDirectChildrenResponseError = undefined;
export interface GetFolderDirectChildrenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent folder.
     */
    id: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of items per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: string;
}
declare type GetFolderDirectChildrenResponseOKType = {
    results?: Array<ChildrenResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetFolderDirectChildrenResponseOK extends GetFolderDirectChildrenResponseOKType {
}
export declare type GetFolderDirectChildrenResponseError = undefined;
export interface GetChildPagesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent page. If you don't know the page ID, use Get pages and filter the results.
     */
    id: number | string;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of pages per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: string;
}
declare type GetChildPagesResponseOKType = {
    results?: Array<ChildPageAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetChildPagesResponseOK extends GetChildPagesResponseOKType {
}
export declare type GetChildPagesResponseError = undefined;
export interface GetPageDirectChildrenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent page.
     */
    id: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of items per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: string;
}
declare type GetPageDirectChildrenResponseOKType = {
    results?: Array<ChildrenResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetPageDirectChildrenResponseOK extends GetPageDirectChildrenResponseOKType {
}
export declare type GetPageDirectChildrenResponseError = undefined;
export interface GetChildCustomContentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent custom content. If you don't know the custom content ID, use Get custom-content and filter the results.
     */
    id: number | string;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of pages per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: string;
}
declare type GetChildCustomContentResponseOKType = {
    results?: Array<ChildCustomContentAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetChildCustomContentResponseOK extends GetChildCustomContentResponseOKType {
}
export declare type GetChildCustomContentResponseError = undefined;
export {};
//# sourceMappingURL=children.d.ts.map