/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../../definitions/PrimaryBodyRepresentation";
import { CommentSortOrder } from "../../definitions/CommentSortOrder";
import { AttachmentCommentModelAsResponse } from "../../definitions/AttachmentCommentModelAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetAttachmentCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment for which comments should be returned.
     */
    id: string;
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of comments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: CommentSortOrder;
    /**
     * Version number of the attachment to retrieve comments for. If no version provided, retrieves comments for the latest version.
     */
    version?: number;
}
declare type GetAttachmentCommentsResponseOKType = {
    results?: Array<AttachmentCommentModelAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetAttachmentCommentsResponseOK extends GetAttachmentCommentsResponseOKType {
}
export declare type GetAttachmentCommentsResponseError = undefined;
export {};
//# sourceMappingURL=attachment.d.ts.map