/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../../definitions/PrimaryBodyRepresentation";
import { CommentSortOrder } from "../../definitions/CommentSortOrder";
import { FooterCommentModelAsResponse } from "../../definitions/FooterCommentModelAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { FooterCommentModel } from "../../definitions/FooterCommentModel";
import { PrimaryBodyRepresentationSingle } from "../../definitions/PrimaryBodyRepresentationSingle";
import { UpdateFooterCommentModel } from "../../definitions/UpdateFooterCommentModel";
import { UpdateFooterCommentModelAsResponse } from "../../definitions/UpdateFooterCommentModelAsResponse";
import { ChildrenCommentModelAsResponse } from "../../definitions/ChildrenCommentModelAsResponse";
export interface GetFooterCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: CommentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of footer comments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetFooterCommentsResponseOKType = {
    results?: Array<FooterCommentModelAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetFooterCommentsResponseOK extends GetFooterCommentsResponseOKType {
}
export declare type GetFooterCommentsResponseError = undefined;
export interface CreateFooterCommentRequest extends HeadersOption, ErrorStrategyOption {
    body: FooterCommentModel & {
        _links?: {
            /**
             * Base url of the Confluence site.
             */
            base?: string;
        };
    };
}
declare type CreateFooterCommentResponseOKType = FooterCommentModelAsResponse;
export interface CreateFooterCommentResponseOK extends CreateFooterCommentResponseOKType {
}
export declare type CreateFooterCommentResponseError = undefined;
export interface GetFooterCommentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment to be retrieved.
     */
    commentId: number | string;
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentationSingle;
    /**
     * Allows you to retrieve a previously published version. Specify the previous version's number to retrieve its details.
     */
    version?: number;
    /**
  * Includes content properties associated with this footer comment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
    /**
  * Includes operations associated with this footer comment in the response, as defined in the `Operation` object.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes likes associated with this footer comment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-likes"?: boolean;
    /**
  * Includes versions associated with this footer comment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-versions"?: boolean;
    /**
  * Includes the current version associated with this footer comment in the response.
  By default this is included and can be omitted by setting the value to `false`.
  */
    "include-version"?: boolean;
}
export declare type GetFooterCommentByIdResponseOK = FooterCommentModelAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type GetFooterCommentByIdResponseError = undefined;
export interface UpdateFooterCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment to be retrieved.
     */
    commentId: number | string;
    body: UpdateFooterCommentModel;
}
export declare type UpdateFooterCommentResponseOK = UpdateFooterCommentModelAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type UpdateFooterCommentResponseError = undefined;
export interface DeleteFooterCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment to be retrieved.
     */
    commentId: number | string;
}
export declare type DeleteFooterCommentResponseOK = undefined;
export declare type DeleteFooterCommentResponseError = undefined;
export interface GetChildrenFooterCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent comment for which footer comment children should be returned.
     */
    id: number | string;
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: CommentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of footer comments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetChildrenFooterCommentsResponseOKType = {
    results?: Array<ChildrenCommentModelAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetChildrenFooterCommentsResponseOK extends GetChildrenFooterCommentsResponseOKType {
}
export declare type GetChildrenFooterCommentsResponseError = undefined;
export {};
//# sourceMappingURL=footer.d.ts.map