/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../../definitions/PrimaryBodyRepresentation";
import { CommentSortOrder } from "../../definitions/CommentSortOrder";
import { InlineCommentModelAsResponse } from "../../definitions/InlineCommentModelAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { CreateInlineCommentModel } from "../../definitions/CreateInlineCommentModel";
import { PrimaryBodyRepresentationSingle } from "../../definitions/PrimaryBodyRepresentationSingle";
import { UpdateInlineCommentModel } from "../../definitions/UpdateInlineCommentModel";
import { InlineCommentChildrenModelAsResponse } from "../../definitions/InlineCommentChildrenModelAsResponse";
export interface GetInlineCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: CommentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of footer comments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetInlineCommentsResponseOKType = {
    results?: Array<InlineCommentModelAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetInlineCommentsResponseOK extends GetInlineCommentsResponseOKType {
}
export declare type GetInlineCommentsResponseError = undefined;
export interface CreateInlineCommentRequest extends HeadersOption, ErrorStrategyOption {
    body: CreateInlineCommentModel;
}
export declare type CreateInlineCommentResponseOK = InlineCommentModelAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type CreateInlineCommentResponseError = undefined;
export interface GetInlineCommentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment to be retrieved.
     */
    commentId: number | string;
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentationSingle;
    /**
     * Allows you to retrieve a previously published version. Specify the previous version's number to retrieve its details.
     */
    version?: number;
    /**
  * Includes content properties associated with this inline comment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
    /**
  * Includes operations associated with this inline comment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes likes associated with this inline comment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-likes"?: boolean;
    /**
  * Includes versions associated with this inline comment in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-versions"?: boolean;
    /**
  * Includes the current version associated with this inline comment in the response.
  By default this is included and can be omitted by setting the value to `false`.
  */
    "include-version"?: boolean;
}
export declare type GetInlineCommentByIdResponseOK = InlineCommentModelAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type GetInlineCommentByIdResponseError = undefined;
export interface UpdateInlineCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment to be retrieved.
     */
    commentId: number | string;
    body: UpdateInlineCommentModel;
}
export declare type UpdateInlineCommentResponseOK = InlineCommentModelAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type UpdateInlineCommentResponseError = undefined;
export interface DeleteInlineCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment to be deleted.
     */
    commentId: number | string;
}
export declare type DeleteInlineCommentResponseOK = undefined;
export declare type DeleteInlineCommentResponseError = undefined;
export interface GetChildrenInlineCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the parent comment for which inline comment children should be returned.
     */
    id: number | string;
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: CommentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of footer comments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetChildrenInlineCommentsResponseOKType = {
    results?: Array<InlineCommentChildrenModelAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetChildrenInlineCommentsResponseOK extends GetChildrenInlineCommentsResponseOKType {
}
export declare type GetChildrenInlineCommentsResponseError = undefined;
export {};
//# sourceMappingURL=inline.d.ts.map