/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../../../definitions/PrimaryBodyRepresentation";
import { CommentSortOrder } from "../../../definitions/CommentSortOrder";
import { BlogPostInlineCommentModelAsResponse } from "../../../definitions/BlogPostInlineCommentModelAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetInlineCommentsForFooterRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post for which inline comments should be returned.
     */
    id: number | string;
    /**
     * The content format type to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Filter the inline comment being retrieved by its status.
     */
    status?: Array<"current" | "deleted" | "trashed" | "historical" | "draft">;
    /**
     * Filter the inline comment being retrieved by its resolution status.
     */
    "resolution-status"?: Array<"resolved" | "open" | "dangling" | "reopened">;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: CommentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of inline comments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetInlineCommentsForFooterResponseOKType = {
    results?: Array<BlogPostInlineCommentModelAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetInlineCommentsForFooterResponseOK extends GetInlineCommentsForFooterResponseOKType {
}
export declare type GetInlineCommentsForFooterResponseError = undefined;
export {};
//# sourceMappingURL=blogPost.d.ts.map