/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertySortOrder } from "../../../definitions/ContentPropertySortOrder";
import { ContentPropertyAsResponse } from "../../../definitions/ContentPropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreateRequest } from "../../../definitions/ContentPropertyCreateRequest";
import { ContentPropertyUpdateRequest } from "../../../definitions/ContentPropertyUpdateRequest";
export interface GetContentPropertiesForAttachmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment for which content properties should be returned.
     */
    attachmentId: string;
    /**
     * Filters the response to return a specific content property with matching key (case sensitive).
     */
    key?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: ContentPropertySortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetContentPropertiesForAttachmentResponseOKType = {
    results?: Array<ContentPropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetContentPropertiesForAttachmentResponseOK extends GetContentPropertiesForAttachmentResponseOKType {
}
export declare type GetContentPropertiesForAttachmentResponseError = undefined;
export interface CreateContentPropertyForAttachmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment to create a property for.
     */
    attachmentId: string;
    body: ContentPropertyCreateRequest;
}
declare type CreateContentPropertyForAttachmentResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForAttachmentResponseOK extends CreateContentPropertyForAttachmentResponseOKType {
}
export declare type CreateContentPropertyForAttachmentResponseError = undefined;
export interface GetContentPropertyForAttachmentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment for which content properties should be returned.
     */
    attachmentId: string;
    /**
     * The ID of the content property to be returned
     */
    propertyId: number;
}
declare type GetContentPropertyForAttachmentByIdResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyForAttachmentByIdResponseOK extends GetContentPropertyForAttachmentByIdResponseOKType {
}
export declare type GetContentPropertyForAttachmentByIdResponseError = undefined;
export interface UpdateContentPropertyForAttachmentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment the property belongs to.
     */
    attachmentId: string;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number;
    body: ContentPropertyUpdateRequest;
}
declare type UpdateContentPropertyForAttachmentByIdResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyForAttachmentByIdResponseOK extends UpdateContentPropertyForAttachmentByIdResponseOKType {
}
export declare type UpdateContentPropertyForAttachmentByIdResponseError = undefined;
export interface DeleteContentPropertyForAttachmentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the attachment the property belongs to.
     */
    attachmentId: string;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number;
}
export declare type DeleteContentPropertyForAttachmentByIdResponseOK = undefined;
export declare type DeleteContentPropertyForAttachmentByIdResponseError = undefined;
export {};
//# sourceMappingURL=attachment.d.ts.map