/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertySortOrder } from "../../../definitions/ContentPropertySortOrder";
import { ContentPropertyAsResponse } from "../../../definitions/ContentPropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreateRequest } from "../../../definitions/ContentPropertyCreateRequest";
import { ContentPropertyUpdateRequest } from "../../../definitions/ContentPropertyUpdateRequest";
export interface GetContentPropertiesForBlogPostRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post for which content properties should be returned.
     */
    blogPostId: number | string;
    /**
     * Filters the response to return a specific content property with matching key (case sensitive).
     */
    key?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: ContentPropertySortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetContentPropertiesForBlogPostResponseOKType = {
    results?: Array<ContentPropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetContentPropertiesForBlogPostResponseOK extends GetContentPropertiesForBlogPostResponseOKType {
}
export declare type GetContentPropertiesForBlogPostResponseError = undefined;
export interface CreateContentPropertyForBlogPostRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post to create a property for.
     */
    blogPostId: number | string;
    body: ContentPropertyCreateRequest;
}
declare type CreateContentPropertyForBlogPostResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForBlogPostResponseOK extends CreateContentPropertyForBlogPostResponseOKType {
}
export declare type CreateContentPropertyForBlogPostResponseError = undefined;
export interface GetContentPropertyForBlogPostByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post for which content properties should be returned.
     */
    blogPostId: number | string;
    /**
     * The ID of the property being requested
     */
    propertyId: number | string;
}
declare type GetContentPropertyForBlogPostByIdResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyForBlogPostByIdResponseOK extends GetContentPropertyForBlogPostByIdResponseOKType {
}
export declare type GetContentPropertyForBlogPostByIdResponseError = undefined;
export interface UpdateContentPropertyForBlogPostByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post the property belongs to.
     */
    blogPostId: number | string;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number | string;
    body: ContentPropertyUpdateRequest;
}
declare type UpdateContentPropertyForBlogPostByIdResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyForBlogPostByIdResponseOK extends UpdateContentPropertyForBlogPostByIdResponseOKType {
}
export declare type UpdateContentPropertyForBlogPostByIdResponseError = undefined;
export interface DeleteContentPropertyForBlogPostByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post the property belongs to.
     */
    blogPostId: number | string;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number | string;
}
export declare type DeleteContentPropertyForBlogPostByIdResponseOK = undefined;
export declare type DeleteContentPropertyForBlogPostByIdResponseError = undefined;
export {};
//# sourceMappingURL=blogPost.d.ts.map