/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertySortOrder } from "../../../definitions/ContentPropertySortOrder";
import { ContentPropertyAsResponse } from "../../../definitions/ContentPropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreateRequest } from "../../../definitions/ContentPropertyCreateRequest";
import { ContentPropertyUpdateRequest } from "../../../definitions/ContentPropertyUpdateRequest";
export interface GetContentPropertiesForCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment for which content properties should be returned.
     */
    commentId: number | string;
    /**
     * Filters the response to return a specific content property with matching key (case sensitive).
     */
    key?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: ContentPropertySortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetContentPropertiesForCommentResponseOKType = {
    results?: Array<ContentPropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetContentPropertiesForCommentResponseOK extends GetContentPropertiesForCommentResponseOKType {
}
export declare type GetContentPropertiesForCommentResponseError = undefined;
export interface CreateContentPropertyForCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment to create a property for.
     */
    commentId: number | string;
    body: ContentPropertyCreateRequest;
}
declare type CreateContentPropertyForCommentResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForCommentResponseOK extends CreateContentPropertyForCommentResponseOKType {
}
export declare type CreateContentPropertyForCommentResponseError = undefined;
export interface GetContentPropertyForCommentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment for which content properties should be returned.
     */
    commentId: number | string;
    /**
     * The ID of the content property being requested.
     */
    propertyId: number | string;
}
declare type GetContentPropertyForCommentByIdResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyForCommentByIdResponseOK extends GetContentPropertyForCommentByIdResponseOKType {
}
export declare type GetContentPropertyForCommentByIdResponseError = undefined;
export interface UpdateContentPropertyForCommentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment the property belongs to.
     */
    commentId: number | string;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number | string;
    body: ContentPropertyUpdateRequest;
}
declare type UpdateContentPropertyForCommentByIdResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyForCommentByIdResponseOK extends UpdateContentPropertyForCommentByIdResponseOKType {
}
export declare type UpdateContentPropertyForCommentByIdResponseError = undefined;
export interface DeleteContentPropertyForCommentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the comment the property belongs to.
     */
    commentId: number | string;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number | string;
}
export declare type DeleteContentPropertyForCommentByIdResponseOK = undefined;
export declare type DeleteContentPropertyForCommentByIdResponseError = undefined;
export {};
//# sourceMappingURL=comment.d.ts.map