/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertySortOrder } from "../../../definitions/ContentPropertySortOrder";
import { ContentPropertyAsResponse } from "../../../definitions/ContentPropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreateRequest } from "../../../definitions/ContentPropertyCreateRequest";
import { ContentPropertyUpdateRequest } from "../../../definitions/ContentPropertyUpdateRequest";
export interface GetContentPropertiesForCustomContentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom content for which content properties should be returned.
     */
    customContentId: number | string;
    /**
     * Filters the response to return a specific content property with matching key (case sensitive).
     */
    key?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: ContentPropertySortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetContentPropertiesForCustomContentResponseOKType = {
    results?: Array<ContentPropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetContentPropertiesForCustomContentResponseOK extends GetContentPropertiesForCustomContentResponseOKType {
}
export declare type GetContentPropertiesForCustomContentResponseError = undefined;
export interface CreateContentPropertyForCustomContentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom content to create a property for.
     */
    customContentId: number | string;
    body: ContentPropertyCreateRequest;
}
declare type CreateContentPropertyForCustomContentResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForCustomContentResponseOK extends CreateContentPropertyForCustomContentResponseOKType {
}
export declare type CreateContentPropertyForCustomContentResponseError = undefined;
export interface GetContentPropertyForCustomContentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom content for which content properties should be returned.
     */
    customContentId: number | string;
    /**
     * The ID of the content property being requested.
     */
    propertyId: number | string;
}
declare type GetContentPropertyForCustomContentByIdResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyForCustomContentByIdResponseOK extends GetContentPropertyForCustomContentByIdResponseOKType {
}
export declare type GetContentPropertyForCustomContentByIdResponseError = undefined;
export interface UpdateContentPropertyByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom content the property belongs to.
     */
    customContentId: number | string;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number | string;
    body: ContentPropertyUpdateRequest;
}
declare type UpdateContentPropertyByIdResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyByIdResponseOK extends UpdateContentPropertyByIdResponseOKType {
}
export declare type UpdateContentPropertyByIdResponseError = undefined;
export interface DeleteContentPropertyForCustomContentByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom content the property belongs to.
     */
    customContentId: number | string;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number | string;
}
export declare type DeleteContentPropertyForCustomContentByIdResponseOK = undefined;
export declare type DeleteContentPropertyForCustomContentByIdResponseError = undefined;
export {};
//# sourceMappingURL=customContent.d.ts.map