/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertySortOrder } from "../../../definitions/ContentPropertySortOrder";
import { ContentPropertyAsResponse } from "../../../definitions/ContentPropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreateRequest } from "../../../definitions/ContentPropertyCreateRequest";
import { ContentPropertyUpdateRequest } from "../../../definitions/ContentPropertyUpdateRequest";
export interface GetContentPropertiesForFolderRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder for which content properties should be returned.
     */
    id: number;
    /**
     * Filters the response to return a specific content property with matching key (case sensitive).
     */
    key?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: ContentPropertySortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetContentPropertiesForFolderResponseOKType = {
    results?: Array<ContentPropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetContentPropertiesForFolderResponseOK extends GetContentPropertiesForFolderResponseOKType {
}
export declare type GetContentPropertiesForFolderResponseError = undefined;
export interface CreateContentPropertyForFolderRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder to create a property for.
     */
    id: number;
    body: ContentPropertyCreateRequest;
}
declare type CreateContentPropertyForFolderResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForFolderResponseOK extends CreateContentPropertyForFolderResponseOKType {
}
export declare type CreateContentPropertyForFolderResponseError = undefined;
export interface GetContentPropertyForFolderByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder for which content properties should be returned.
     */
    folderId: number;
    /**
     * The ID of the content property being requested.
     */
    propertyId: number;
}
declare type GetContentPropertyForFolderByIdResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyForFolderByIdResponseOK extends GetContentPropertyForFolderByIdResponseOKType {
}
export declare type GetContentPropertyForFolderByIdResponseError = undefined;
export interface UpdateContentPropertyForFolderByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder the property belongs to.
     */
    folderId: number;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number;
    body: ContentPropertyUpdateRequest;
}
declare type UpdateContentPropertyForFolderByIdResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyForFolderByIdResponseOK extends UpdateContentPropertyForFolderByIdResponseOKType {
}
export declare type UpdateContentPropertyForFolderByIdResponseError = undefined;
export interface DeleteContentPropertyForFolderByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder the property belongs to.
     */
    folderId: number;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number;
}
export declare type DeleteContentPropertyForFolderByIdResponseOK = undefined;
export declare type DeleteContentPropertyForFolderByIdResponseError = undefined;
export {};
//# sourceMappingURL=folder.d.ts.map