/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertySortOrder } from "../../../definitions/ContentPropertySortOrder";
import { ContentPropertyAsResponse } from "../../../definitions/ContentPropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreateRequest } from "../../../definitions/ContentPropertyCreateRequest";
import { ContentPropertyUpdateRequest } from "../../../definitions/ContentPropertyUpdateRequest";
export interface GetContentPropertiesForPageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page for which content properties should be returned.
     */
    pageId: number | string;
    /**
     * Filters the response to return a specific content property with matching key (case sensitive).
     */
    key?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: ContentPropertySortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetContentPropertiesForPageResponseOKType = {
    results?: Array<ContentPropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetContentPropertiesForPageResponseOK extends GetContentPropertiesForPageResponseOKType {
}
export declare type GetContentPropertiesForPageResponseError = undefined;
export interface CreateContentPropertyForPageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page to create a property for.
     */
    pageId: number | string;
    body: ContentPropertyCreateRequest;
}
declare type CreateContentPropertyForPageResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForPageResponseOK extends CreateContentPropertyForPageResponseOKType {
}
export declare type CreateContentPropertyForPageResponseError = undefined;
export interface GetContentPropertyForPageByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page for which content properties should be returned.
     */
    pageId: number | string;
    /**
     * The ID of the content property being requested.
     */
    propertyId: number | string;
}
declare type GetContentPropertyForPageByIdResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyForPageByIdResponseOK extends GetContentPropertyForPageByIdResponseOKType {
}
export declare type GetContentPropertyForPageByIdResponseError = undefined;
export interface UpdateContentPropertyForPageByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page the property belongs to.
     */
    pageId: number | string;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number | string;
    body: ContentPropertyUpdateRequest;
}
declare type UpdateContentPropertyForPageByIdResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyForPageByIdResponseOK extends UpdateContentPropertyForPageByIdResponseOKType {
}
export declare type UpdateContentPropertyForPageByIdResponseError = undefined;
export interface DeleteContentPropertyForPageByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page the property belongs to.
     */
    pageId: number | string;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number | string;
}
export declare type DeleteContentPropertyForPageByIdResponseOK = undefined;
export declare type DeleteContentPropertyForPageByIdResponseError = undefined;
export {};
//# sourceMappingURL=page.d.ts.map