/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertySortOrder } from "../../../definitions/ContentPropertySortOrder";
import { ContentPropertyAsResponse } from "../../../definitions/ContentPropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreateRequest } from "../../../definitions/ContentPropertyCreateRequest";
import { ContentPropertyUpdateRequest } from "../../../definitions/ContentPropertyUpdateRequest";
export interface GetContentPropertiesForWhiteboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard for which content properties should be returned.
     */
    id: number;
    /**
     * Filters the response to return a specific content property with matching key (case sensitive).
     */
    key?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: ContentPropertySortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of attachments per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetContentPropertiesForWhiteboardResponseOKType = {
    results?: Array<ContentPropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetContentPropertiesForWhiteboardResponseOK extends GetContentPropertiesForWhiteboardResponseOKType {
}
export declare type GetContentPropertiesForWhiteboardResponseError = undefined;
export interface CreateContentPropertyForWhiteboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard to create a property for.
     */
    id: number;
    body: ContentPropertyCreateRequest;
}
declare type CreateContentPropertyForWhiteboardResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForWhiteboardResponseOK extends CreateContentPropertyForWhiteboardResponseOKType {
}
export declare type CreateContentPropertyForWhiteboardResponseError = undefined;
export interface GetContentPropertyForWhiteboardByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard for which content properties should be returned.
     */
    whiteboardId: number;
    /**
     * The ID of the content property being requested.
     */
    propertyId: number;
}
declare type GetContentPropertyForWhiteboardByIdResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyForWhiteboardByIdResponseOK extends GetContentPropertyForWhiteboardByIdResponseOKType {
}
export declare type GetContentPropertyForWhiteboardByIdResponseError = undefined;
export interface UpdateContentPropertyForWhiteboardByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard the property belongs to.
     */
    whiteboardId: number;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number;
    body: ContentPropertyUpdateRequest;
}
declare type UpdateContentPropertyForWhiteboardByIdResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyForWhiteboardByIdResponseOK extends UpdateContentPropertyForWhiteboardByIdResponseOKType {
}
export declare type UpdateContentPropertyForWhiteboardByIdResponseError = undefined;
export interface DeleteContentPropertyForWhiteboardByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard the property belongs to.
     */
    whiteboardId: number;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number;
}
export declare type DeleteContentPropertyForWhiteboardByIdResponseOK = undefined;
export declare type DeleteContentPropertyForWhiteboardByIdResponseError = undefined;
export {};
//# sourceMappingURL=whiteboard.d.ts.map