/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CustomContentSortOrder } from "../../definitions/CustomContentSortOrder";
import { CustomContentBodyRepresentation } from "../../definitions/CustomContentBodyRepresentation";
import { CustomContentBulkAsResponse } from "../../definitions/CustomContentBulkAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetCustomContentByTypeInPageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page for which custom content should be returned.
     */
    id: number | string;
    /**
     * The type of custom content being requested. See: https://developer.atlassian.com/cloud/confluence/custom-content/ for additional details on custom content.
     */
    type: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: CustomContentSortOrder;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of pages per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
  * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
  
  Note: If the custom content body type is `storage`, the `storage` and `atlas_doc_format` body formats are able to be returned. If the custom content body type is `raw`, only the `raw` body format is able to be returned.
  */
    "body-format"?: CustomContentBodyRepresentation;
}
declare type GetCustomContentByTypeInPageResponseOKType = {
    results?: Array<CustomContentBulkAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetCustomContentByTypeInPageResponseOK extends GetCustomContentByTypeInPageResponseOKType {
}
export declare type GetCustomContentByTypeInPageResponseError = undefined;
export {};
//# sourceMappingURL=page.d.ts.map