/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DatabaseSingleAsResponse } from "../definitions/DatabaseSingleAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentStatusAsResponse } from "../definitions/ContentStatusAsResponse";
import { ParentContentTypeAsResponse } from "../definitions/ParentContentTypeAsResponse";
import { VersionAsResponse } from "../definitions/VersionAsResponse";
import { ChildrenResponseAsResponse } from "../definitions/ChildrenResponseAsResponse";
import { OptionalFieldMetaAsResponse } from "../definitions/OptionalFieldMetaAsResponse";
import { OptionalFieldLinksAsResponse } from "../definitions/OptionalFieldLinksAsResponse";
import { OperationAsResponse } from "../definitions/OperationAsResponse";
import { ContentPropertyAsResponse } from "../definitions/ContentPropertyAsResponse";
export interface CreateDatabaseRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The database will be private. Only the user who creates this database will have permission to view and edit one.
     */
    private?: boolean;
    body: {
        /**
         * ID of the space.
         */
        spaceId: string;
        /**
         * Title of the database.
         */
        title?: string;
        /**
         * The parent content ID of the database.
         */
        parentId?: string;
    };
}
export declare type CreateDatabaseResponseOK = DatabaseSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
        /**
         * Web UI link of the content.
         */
        webui?: string;
        /**
         * Edit UI link of the content.
         */
        editui?: string;
        edituiv2?: string;
        tinyui?: string;
    };
};
export declare type CreateDatabaseResponseError = undefined;
export interface GetDatabaseByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the database to be returned
     */
    id: number;
    /**
     * Includes collaborators on the database.
     */
    "include-collaborators"?: boolean;
    /**
     * Includes direct children of the database, as defined in the `ChildrenResponse` object.
     */
    "include-direct-children"?: boolean;
    /**
  * Includes operations associated with this database in the response, as defined in the `Operation` object.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes content properties associated with this database in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
}
declare type GetDatabaseByIdResponseOKType = {
    /**
     * ID of the database.
     */
    id?: string;
    /**
     * The content type of the object.
     */
    type?: string;
    status?: ContentStatusAsResponse;
    /**
     * Title of the database.
     */
    title?: string;
    /**
     * ID of the parent content, or null if there is no parent content.
     */
    parentId?: string;
    parentType?: ParentContentTypeAsResponse;
    /**
     * Position of the database within the given parent page tree.
     */
    position?: number;
    /**
     * The account ID of the user who created this database originally.
     */
    authorId?: string;
    /**
     * The account ID of the user who owns this database.
     */
    ownerId?: string;
    /**
     * Date and time when the database was created. In format "YYYY-MM-DDTHH:mm:ss.sssZ".
     */
    createdAt?: string;
    version?: VersionAsResponse;
    collaborators?: Array<{
        accountId?: string;
    }>;
    directChildren?: {
        results?: Array<ChildrenResponseAsResponse>;
        meta?: OptionalFieldMetaAsResponse;
        _links?: OptionalFieldLinksAsResponse;
    };
    operations?: {
        results?: Array<OperationAsResponse>;
        meta?: OptionalFieldMetaAsResponse;
        _links?: OptionalFieldLinksAsResponse;
    };
    properties?: {
        results?: Array<ContentPropertyAsResponse>;
        meta?: OptionalFieldMetaAsResponse;
        _links?: OptionalFieldLinksAsResponse;
    };
    _links?: {
        /**
         * Base URL of the Confluence site.
         */
        base?: string;
        /**
         * Web UI link of the content.
         */
        webui?: string;
        /**
         * Edit UI link of the content.
         */
        editui?: string;
        edituiv2?: string;
        tinyui?: string;
    };
};
export interface GetDatabaseByIdResponseOK extends GetDatabaseByIdResponseOKType {
}
export declare type GetDatabaseByIdResponseError = undefined;
export interface DeleteDatabaseRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the database to be deleted.
     */
    id: number;
}
export declare type DeleteDatabaseResponseOK = undefined;
export declare type DeleteDatabaseResponseError = undefined;
export {};
//# sourceMappingURL=database.d.ts.map