/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DescendantsResponseAsResponse } from "../definitions/DescendantsResponseAsResponse";
import { MultiEntityLinksAsResponse } from "../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetWhiteboardDescendantsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard.
     */
    id: number;
    /**
     * Maximum number of items per result to return. If more results exist, call the endpoint with the cursor to fetch the next set of results.
     */
    limit?: number;
    /**
     * Maximum depth of descendants to return. If more results are required, use the endpoint corresponding to the content type of the deepest descendant to fetch more descendants.
     */
    depth?: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
}
declare type GetWhiteboardDescendantsResponseOKType = {
    results?: Array<DescendantsResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetWhiteboardDescendantsResponseOK extends GetWhiteboardDescendantsResponseOKType {
}
export declare type GetWhiteboardDescendantsResponseError = undefined;
export interface GetDatabaseDescendantsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the database.
     */
    id: number;
    /**
     * Maximum number of items per result to return. If more results exist, call the endpoint with the cursor to fetch the next set of results.
     */
    limit?: number;
    /**
     * Maximum depth of descendants to return. If more results required, call the endpoint with the id of deepest descendant to fetch more descendants.
     */
    depth?: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
}
declare type GetDatabaseDescendantsResponseOKType = {
    results?: Array<DescendantsResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetDatabaseDescendantsResponseOK extends GetDatabaseDescendantsResponseOKType {
}
export declare type GetDatabaseDescendantsResponseError = undefined;
export interface GetSmartLinkDescendantsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the smart link.
     */
    id: number;
    /**
     * Maximum depth of descendants to return. If more results are required, use the endpoint corresponding to the content type of the deepest descendant to fetch more descendants.
     */
    limit?: number;
    /**
     * Maximum depth of descendants to return. If more results required, call the endpoint with the id of deepest descendant to fetch more descendants.
     */
    depth?: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
}
declare type GetSmartLinkDescendantsResponseOKType = {
    results?: Array<DescendantsResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetSmartLinkDescendantsResponseOK extends GetSmartLinkDescendantsResponseOKType {
}
export declare type GetSmartLinkDescendantsResponseError = undefined;
export interface GetFolderDescendantsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder.
     */
    id: number;
    /**
     * Maximum number of items per result to return. If more results exist, call the endpoint with the cursor to fetch the next set of results.
     */
    limit?: number;
    /**
     * Maximum depth of descendants to return. If more results are required, use the endpoint corresponding to the content type of the deepest descendant to fetch more descendants.
     */
    depth?: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
}
declare type GetFolderDescendantsResponseOKType = {
    results?: Array<DescendantsResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetFolderDescendantsResponseOK extends GetFolderDescendantsResponseOKType {
}
export declare type GetFolderDescendantsResponseError = undefined;
export interface GetPageDescendantsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page.
     */
    id: number;
    /**
     * Maximum number of items per result to return. If more results exist, call the endpoint with the cursor to fetch the next set of results.
     */
    limit?: number;
    /**
     * Maximum depth of descendants to return. If more results are required, use the endpoint corresponding to the content type of the deepest descendant to fetch more descendants.
     */
    depth?: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
}
declare type GetPageDescendantsResponseOKType = {
    results?: Array<DescendantsResponseAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetPageDescendantsResponseOK extends GetPageDescendantsResponseOKType {
}
export declare type GetPageDescendantsResponseError = undefined;
export {};
//# sourceMappingURL=descendant.d.ts.map