/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { FolderSingleAsResponse } from "../definitions/FolderSingleAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface CreateFolderRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * ID of the space.
         */
        spaceId: string;
        /**
         * Title of the folder.
         */
        title?: string;
        /**
         * The parent content ID of the folder.
         */
        parentId?: string;
    };
}
export declare type CreateFolderResponseOK = FolderSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
        /**
         * Web UI link of the content.
         */
        webui?: string;
        /**
         * Edit UI link of the content.
         */
        editui?: string;
        edituiv2?: string;
        tinyui?: string;
    };
};
export declare type CreateFolderResponseError = undefined;
export interface GetFolderByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder to be returned.
     */
    id: number;
    /**
     * Includes collaborators on the folder.
     */
    "include-collaborators"?: boolean;
    /**
     * Includes direct children of the folder, as defined in the `ChildrenResponse` object.
     */
    "include-direct-children"?: boolean;
    /**
  * Includes operations associated with this folder in the response, as defined in the `Operation` object.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes content properties associated with this folder in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
}
export declare type GetFolderByIdResponseOK = FolderSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
        /**
         * Web UI link of the content.
         */
        webui?: string;
        /**
         * Edit UI link of the content.
         */
        editui?: string;
        edituiv2?: string;
        tinyui?: string;
    };
};
export declare type GetFolderByIdResponseError = undefined;
export interface DeleteFolderRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the folder to be deleted.
     */
    id: number;
}
export declare type DeleteFolderResponseOK = undefined;
export declare type DeleteFolderResponseError = undefined;
//# sourceMappingURL=folder.d.ts.map