/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SmartLinkSingleAsResponse } from "../definitions/SmartLinkSingleAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentStatusAsResponse } from "../definitions/ContentStatusAsResponse";
import { ParentContentTypeAsResponse } from "../definitions/ParentContentTypeAsResponse";
import { VersionAsResponse } from "../definitions/VersionAsResponse";
import { ChildrenResponseAsResponse } from "../definitions/ChildrenResponseAsResponse";
import { OptionalFieldMetaAsResponse } from "../definitions/OptionalFieldMetaAsResponse";
import { OptionalFieldLinksAsResponse } from "../definitions/OptionalFieldLinksAsResponse";
import { OperationAsResponse } from "../definitions/OperationAsResponse";
import { ContentPropertyAsResponse } from "../definitions/ContentPropertyAsResponse";
export interface CreateSmartLinkRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * ID of the space.
         */
        spaceId: string;
        /**
         * Title of the Smart Link in the content tree.
         */
        title?: string;
        /**
         * The parent content ID of the Smart Link in the content tree.
         */
        parentId?: string;
        /**
         * The URL that the Smart Link in the content tree should be populated with.
         */
        embedUrl?: string;
    };
}
export declare type CreateSmartLinkResponseOK = SmartLinkSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
        /**
         * Web UI link of the content.
         */
        webui?: string;
        /**
         * Edit UI link of the content.
         */
        editui?: string;
        edituiv2?: string;
        tinyui?: string;
    };
};
export declare type CreateSmartLinkResponseError = undefined;
export interface GetSmartLinkByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the Smart Link in the content tree to be returned.
     */
    id: number;
    /**
     * Includes collaborators on the Smart Link.
     */
    "include-collaborators"?: boolean;
    /**
     * Includes direct children of the Smart Link, as defined in the `ChildrenResponse` object.
     */
    "include-direct-children"?: boolean;
    /**
  * Includes operations associated with this Smart Link in the response, as defined in the `Operation` object.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes content properties associated with this Smart Link in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
}
export declare type GetSmartLinkByIdResponseOK = {
    /**
     * ID of the database.
     */
    id?: string;
    /**
     * The content type of the object.
     */
    type?: string;
    status?: ContentStatusAsResponse;
    /**
     * Title of the database.
     */
    title?: string;
    /**
     * ID of the parent content, or null if there is no parent content.
     */
    parentId?: string;
    parentType?: ParentContentTypeAsResponse;
    /**
     * Position of the database within the given parent page tree.
     */
    position?: number;
    /**
     * The account ID of the user who created this database originally.
     */
    authorId?: string;
    /**
     * The account ID of the user who owns this database.
     */
    ownerId?: string;
    /**
     * Date and time when the database was created. In format "YYYY-MM-DDTHH:mm:ss.sssZ".
     */
    createdAt?: string;
    version?: VersionAsResponse;
    collaborators?: Array<{
        accountId?: string;
    }>;
    directChildren?: {
        results?: Array<ChildrenResponseAsResponse>;
        meta?: OptionalFieldMetaAsResponse;
        _links?: OptionalFieldLinksAsResponse;
    };
    operations?: {
        results?: Array<OperationAsResponse>;
        meta?: OptionalFieldMetaAsResponse;
        _links?: OptionalFieldLinksAsResponse;
    };
    properties?: {
        results?: Array<ContentPropertyAsResponse>;
        meta?: OptionalFieldMetaAsResponse;
        _links?: OptionalFieldLinksAsResponse;
    };
} & {
    _links?: {
        /**
         * Base URL of the Confluence site.
         */
        base?: string;
        /**
         * Web UI link of the content.
         */
        webui?: string;
        /**
         * Edit UI link of the content.
         */
        editui?: string;
        edituiv2?: string;
        tinyui?: string;
    };
};
export declare type GetSmartLinkByIdResponseError = undefined;
export interface DeleteSmartLinkRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the Smart Link in the content tree to be deleted.
     */
    id: number;
}
export declare type DeleteSmartLinkResponseOK = undefined;
export declare type DeleteSmartLinkResponseError = undefined;
//# sourceMappingURL=smartLink.d.ts.map