/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SpaceSortOrder } from "../definitions/SpaceSortOrder";
import { SpaceDescriptionBodyRepresentation } from "../definitions/SpaceDescriptionBodyRepresentation";
import { SpaceBulkAsResponse } from "../definitions/SpaceBulkAsResponse";
import { MultiEntityLinksAsResponse } from "../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { SpaceSingleAsResponse } from "../definitions/SpaceSingleAsResponse";
export interface GetSpacesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Filter the results to spaces based on their IDs. Multiple IDs can be specified as a comma-separated list.
     */
    ids?: Array<number | string>;
    /**
     * Filter the results to spaces based on their keys. Multiple keys can be specified as a comma-separated list.
     */
    keys?: Array<string>;
    /**
     * Filter the results to spaces based on their type.
     */
    type?: "global" | "personal" | "collaboration" | "knowledge_base";
    /**
     * Filter the results to spaces based on their status.
     */
    status?: "current" | "archived";
    /**
     * Filter the results to spaces based on their labels. Multiple labels can be specified as a comma-separated list.
     */
    labels?: Array<string>;
    /**
     * Filter the results to spaces favorited by the user with the specified account ID.
     */
    "favorited-by"?: string;
    /**
     * Filter the results to spaces NOT favorited by the user with the specified account ID.
     */
    "not-favorited-by"?: string;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: SpaceSortOrder;
    /**
     * The content format type to be returned in the `description` field of the response. If available, the representation will be available under a response field of the same name under the `description` field.
     */
    "description-format"?: SpaceDescriptionBodyRepresentation;
    /**
     * If the icon for the space should be fetched or not.
     */
    "include-icon"?: boolean;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of spaces per result to return. If more results exist, use the `Link` response header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetSpacesResponseOKType = {
    results?: Array<SpaceBulkAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetSpacesResponseOK extends GetSpacesResponseOKType {
}
export declare type GetSpacesResponseError = undefined;
export interface GetSpaceByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the space to be returned.
     */
    id: number | string;
    /**
     * The content format type to be returned in the `description` field of the response. If available, the representation will be available under a response field of the same name under the `description` field.
     */
    "description-format"?: SpaceDescriptionBodyRepresentation;
    /**
     * If the icon for the space should be fetched or not.
     */
    "include-icon"?: boolean;
    /**
  * Includes operations associated with this space in the response, as defined in the `Operation` object.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes space properties associated with this space in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
    /**
  * Includes space permissions associated with this space in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-permissions"?: boolean;
    /**
  * Includes labels associated with this space in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-labels"?: boolean;
}
export declare type GetSpaceByIdResponseOK = SpaceSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type GetSpaceByIdResponseError = undefined;
export {};
//# sourceMappingURL=space.d.ts.map