/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SpacePropertyAsResponse } from "../../definitions/SpacePropertyAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { SpacePropertyCreateRequest } from "../../definitions/SpacePropertyCreateRequest";
import { SpacePropertyUpdateRequest } from "../../definitions/SpacePropertyUpdateRequest";
export interface GetSpacePropertiesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the space for which space properties should be returned.
     */
    spaceId: number | string;
    /**
     * The key of the space property to retrieve. This should be used when a user knows the key of their property, but needs to retrieve the id for use in other methods.
     */
    key?: string;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of pages per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetSpacePropertiesResponseOKType = {
    results?: Array<SpacePropertyAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetSpacePropertiesResponseOK extends GetSpacePropertiesResponseOKType {
}
export declare type GetSpacePropertiesResponseError = undefined;
export interface CreateSpacePropertyInSpaceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the space for which space properties should be returned.
     */
    spaceId: number | string;
    body: SpacePropertyCreateRequest;
}
declare type CreateSpacePropertyInSpaceResponseOKType = SpacePropertyAsResponse;
export interface CreateSpacePropertyInSpaceResponseOK extends CreateSpacePropertyInSpaceResponseOKType {
}
export declare type CreateSpacePropertyInSpaceResponseError = undefined;
export interface GetSpacePropertyByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the space the property belongs to.
     */
    spaceId: number | string;
    /**
     * The ID of the property to be retrieved.
     */
    propertyId: number | string;
}
declare type GetSpacePropertyByIdResponseOKType = SpacePropertyAsResponse;
export interface GetSpacePropertyByIdResponseOK extends GetSpacePropertyByIdResponseOKType {
}
export declare type GetSpacePropertyByIdResponseError = undefined;
export interface UpdateSpacePropertyByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the space the property belongs to.
     */
    spaceId: number | string;
    /**
     * The ID of the property to be updated.
     */
    propertyId: number | string;
    body: SpacePropertyUpdateRequest;
}
declare type UpdateSpacePropertyByIdResponseOKType = SpacePropertyAsResponse;
export interface UpdateSpacePropertyByIdResponseOK extends UpdateSpacePropertyByIdResponseOKType {
}
export declare type UpdateSpacePropertyByIdResponseError = undefined;
export interface DeleteSpacePropertyByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the space the property belongs to.
     */
    spaceId: number | string;
    /**
     * The ID of the property to be deleted.
     */
    propertyId: number | string;
}
export declare type DeleteSpacePropertyByIdResponseOK = undefined;
export declare type DeleteSpacePropertyByIdResponseError = undefined;
export {};
//# sourceMappingURL=property.d.ts.map