/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../definitions/PrimaryBodyRepresentation";
import { TaskAsResponse } from "../definitions/TaskAsResponse";
import { MultiEntityLinksAsResponse } from "../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetTasksRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Specifies whether to include blank tasks in the response. Defaults to `true`.
     */
    "include-blank-tasks"?: boolean;
    /**
     * Filters on the status of the task.
     */
    status?: "complete" | "incomplete";
    /**
     * Filters on task ID. Multiple IDs can be specified.
     */
    "task-id"?: Array<number | string>;
    /**
     * Filters on the space ID of the task. Multiple IDs can be specified.
     */
    "space-id"?: Array<number | string>;
    /**
     * Filters on the page ID of the task. Multiple IDs can be specified. Note - page and blog post filters can be used in conjunction.
     */
    "page-id"?: Array<number | string>;
    /**
     * Filters on the blog post ID of the task. Multiple IDs can be specified. Note - page and blog post filters can be used in conjunction.
     */
    "blogpost-id"?: Array<number | string>;
    /**
     * Filters on the Account ID of the user who created this task. Multiple IDs can be specified.
     */
    "created-by"?: Array<string>;
    /**
     * Filters on the Account ID of the user to whom this task is assigned. Multiple IDs can be specified.
     */
    "assigned-to"?: Array<string>;
    /**
     * Filters on the Account ID of the user who completed this task. Multiple IDs can be specified.
     */
    "completed-by"?: Array<string>;
    /**
     * Filters on start of date-time range of task based on creation date (inclusive). Input is epoch time in milliseconds.
     */
    "created-at-from"?: number;
    /**
     * Filters on end of date-time range of task based on creation date (inclusive). Input is epoch time in milliseconds.
     */
    "created-at-to"?: number;
    /**
     * Filters on start of date-time range of task based on due date (inclusive). Input is epoch time in milliseconds.
     */
    "due-at-from"?: number;
    /**
     * Filters on end of date-time range of task based on due date (inclusive). Input is epoch time in milliseconds.
     */
    "due-at-to"?: number;
    /**
     * Filters on start of date-time range of task based on completion date (inclusive). Input is epoch time in milliseconds.
     */
    "completed-at-from"?: number;
    /**
     * Filters on end of date-time range of task based on completion date (inclusive). Input is epoch time in milliseconds.
     */
    "completed-at-to"?: number;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of tasks per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
}
declare type GetTasksResponseOKType = {
    results?: Array<TaskAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetTasksResponseOK extends GetTasksResponseOKType {
}
export declare type GetTasksResponseError = undefined;
export interface GetTaskByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the task to be returned. If you don't know the task ID, use Get tasks and filter the results.
     */
    id: number | string;
    /**
     * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
}
declare type GetTaskByIdResponseOKType = TaskAsResponse;
export interface GetTaskByIdResponseOK extends GetTaskByIdResponseOKType {
}
export declare type GetTaskByIdResponseError = undefined;
export interface UpdateTaskRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the task to be updated. If you don't know the task ID, use Get tasks and filter the results.
     */
    id: number | string;
    /**
     * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    body: {
        /**
         * ID of the task.
         */
        id?: number | string;
        /**
         * Local ID of the task. This ID is local to the corresponding page or blog post.
         */
        localId?: number | string;
        /**
         * ID of the space the task is in.
         */
        spaceId?: number | string;
        /**
         * ID of the page the task is in.
         */
        pageId?: number | string;
        /**
         * ID of the blog post the task is in.
         */
        blogPostId?: number | string;
        /**
         * Status of the task.
         */
        status: "complete" | "incomplete";
        /**
         * Account ID of the user who created this task.
         */
        createdBy?: string;
        /**
         * Account ID of the user to whom this task is assigned.
         */
        assignedTo?: string;
        /**
         * Account ID of the user who completed this task.
         */
        completedBy?: string;
        /**
         * Date and time when the task was created. In format "YYYY-MM-DDTHH:mm:ss.sssZ".
         */
        createdAt?: string;
        /**
         * Date and time when the task was updated. In format "YYYY-MM-DDTHH:mm:ss.sssZ".
         */
        updatedAt?: string;
        /**
         * Date and time when the task is due. In format "YYYY-MM-DDTHH:mm:ss.sssZ".
         */
        dueAt?: string;
        /**
         * Date and time when the task was completed. In format "YYYY-MM-DDTHH:mm:ss.sssZ".
         */
        completedAt?: string;
    };
}
declare type UpdateTaskResponseOKType = TaskAsResponse;
export interface UpdateTaskResponseOK extends UpdateTaskResponseOKType {
}
export declare type UpdateTaskResponseError = undefined;
export {};
//# sourceMappingURL=task.d.ts.map