/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../../definitions/PrimaryBodyRepresentation";
import { VersionSortOrder } from "../../definitions/VersionSortOrder";
import { BlogPostVersionAsResponse } from "../../definitions/BlogPostVersionAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DetailedVersionAsResponse } from "../../definitions/DetailedVersionAsResponse";
export interface GetBlogPostVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post to be queried for its versions. If you don't know the blog post ID, use Get blog posts and filter the results.
     */
    id: number | string;
    /**
     * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of versions per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: VersionSortOrder;
}
declare type GetBlogPostVersionsResponseOKType = {
    results?: Array<BlogPostVersionAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetBlogPostVersionsResponseOK extends GetBlogPostVersionsResponseOKType {
}
export declare type GetBlogPostVersionsResponseError = undefined;
export interface GetVersionDetailsForBlogPostVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the blog post for which version details should be returned.
     */
    blogPostId: number | string;
    /**
     * The version number of the blog post to be returned.
     */
    versionNumber: number;
}
declare type GetVersionDetailsForBlogPostVersionResponseOKType = DetailedVersionAsResponse;
export interface GetVersionDetailsForBlogPostVersionResponseOK extends GetVersionDetailsForBlogPostVersionResponseOKType {
}
export declare type GetVersionDetailsForBlogPostVersionResponseError = undefined;
export {};
//# sourceMappingURL=blogPost.d.ts.map