/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../../../definitions/PrimaryBodyRepresentation";
import { VersionSortOrder } from "../../../definitions/VersionSortOrder";
import { CommentVersionAsResponse } from "../../../definitions/CommentVersionAsResponse";
import { MultiEntityLinksAsResponse } from "../../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DetailedVersionAsResponse } from "../../../definitions/DetailedVersionAsResponse";
export interface GetInlineCommentVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the inline comment for which versions should be returned
     */
    id: number | string;
    /**
     * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of versions per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: VersionSortOrder;
}
declare type GetInlineCommentVersionsResponseOKType = {
    results?: Array<CommentVersionAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetInlineCommentVersionsResponseOK extends GetInlineCommentVersionsResponseOKType {
}
export declare type GetInlineCommentVersionsResponseError = undefined;
export interface GetVersionDetailsForInlineCommentVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the inline comment for which version details should be returned.
     */
    id: number;
    /**
     * The version number of the inline comment to be returned.
     */
    versionNumber: number | string;
}
declare type GetVersionDetailsForInlineCommentVersionResponseOKType = DetailedVersionAsResponse;
export interface GetVersionDetailsForInlineCommentVersionResponseOK extends GetVersionDetailsForInlineCommentVersionResponseOKType {
}
export declare type GetVersionDetailsForInlineCommentVersionResponseError = undefined;
export {};
//# sourceMappingURL=inline.d.ts.map