/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CustomContentBodyRepresentation } from "../../definitions/CustomContentBodyRepresentation";
import { VersionSortOrder } from "../../definitions/VersionSortOrder";
import { CustomContentVersionAsResponse } from "../../definitions/CustomContentVersionAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DetailedVersionAsResponse } from "../../definitions/DetailedVersionAsResponse";
export interface GetCustomContentVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom content to be queried for its versions. If you don't know the custom content ID, use Get custom-content by type and filter the results.
     */
    customContentId: number;
    /**
  * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
  
  Note: If the custom content body type is `storage`, the `storage` and `atlas_doc_format` body formats are able to be returned. If the custom content body type is `raw`, only the `raw` body format is able to be returned.
  */
    "body-format"?: CustomContentBodyRepresentation;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of versions per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: VersionSortOrder;
}
declare type GetCustomContentVersionsResponseOKType = {
    results?: Array<CustomContentVersionAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetCustomContentVersionsResponseOK extends GetCustomContentVersionsResponseOKType {
}
export declare type GetCustomContentVersionsResponseError = undefined;
export interface GetVersionDetailsForCustomContentVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom content for which version details should be returned.
     */
    customContentId: number | string;
    /**
     * The version number of the custom content to be returned.
     */
    versionNumber: number;
}
declare type GetVersionDetailsForCustomContentVersionResponseOKType = DetailedVersionAsResponse;
export interface GetVersionDetailsForCustomContentVersionResponseOK extends GetVersionDetailsForCustomContentVersionResponseOKType {
}
export declare type GetVersionDetailsForCustomContentVersionResponseError = undefined;
export {};
//# sourceMappingURL=customContent.d.ts.map