/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PrimaryBodyRepresentation } from "../../definitions/PrimaryBodyRepresentation";
import { VersionSortOrder } from "../../definitions/VersionSortOrder";
import { PageVersionAsResponse } from "../../definitions/PageVersionAsResponse";
import { MultiEntityLinksAsResponse } from "../../definitions/MultiEntityLinksAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DetailedVersionAsResponse } from "../../definitions/DetailedVersionAsResponse";
export interface GetPageVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page to be queried for its versions. If you don't know the page ID, use Get pages and filter the results.
     */
    id: number | string;
    /**
     * The content format types to be returned in the `body` field of the response. If available, the representation will be available under a response field of the same name under the `body` field.
     */
    "body-format"?: PrimaryBodyRepresentation;
    /**
     * Used for pagination, this opaque cursor will be returned in the `next` URL in the `Link` response header. Use the relative URL in the `Link` header to retrieve the `next` set of results.
     */
    cursor?: string;
    /**
     * Maximum number of versions per result to return. If more results exist, use the `Link` header to retrieve a relative URL that will return the next set of results.
     */
    limit?: number;
    /**
     * Used to sort the result by a particular field.
     */
    sort?: VersionSortOrder;
}
declare type GetPageVersionsResponseOKType = {
    results?: Array<PageVersionAsResponse>;
    _links?: MultiEntityLinksAsResponse;
};
export interface GetPageVersionsResponseOK extends GetPageVersionsResponseOKType {
}
export declare type GetPageVersionsResponseError = undefined;
export interface GetVersionDetailsForPageVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the page for which version details should be returned.
     */
    pageId: number | string;
    /**
     * The version number of the page to be returned.
     */
    versionNumber: number;
}
declare type GetVersionDetailsForPageVersionResponseOKType = DetailedVersionAsResponse;
export interface GetVersionDetailsForPageVersionResponseOK extends GetVersionDetailsForPageVersionResponseOKType {
}
export declare type GetVersionDetailsForPageVersionResponseError = undefined;
export {};
//# sourceMappingURL=page.d.ts.map