/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { WhiteboardSingleAsResponse } from "../definitions/WhiteboardSingleAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface CreateWhiteboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The whiteboard will be private. Only the user who creates this whiteboard will have permission to view and edit one.
     */
    private?: boolean;
    body: {
        /**
         * ID of the space.
         */
        spaceId: string;
        /**
         * Title of the whiteboard.
         */
        title?: string;
        /**
         * The parent content ID of the whiteboard.
         */
        parentId?: string;
        /**
         * Providing a template key will add that template to the new whiteboard.
         */
        templateKey?: "2x2-prioritization" | "4ls-retro" | "annual-calendar" | "brainwriting" | "concept-map" | "crazy-8s" | "daily-sync" | "disruptive-brainstorm" | "dot-voting" | "elevator-pitch" | "flow-chart" | "gap-analysis" | "ice-breakers" | "incident-postmortem" | "journey-mapping-kit" | "kanban-board" | "lean-coffee" | "network-of-teams" | "org-chart" | "pi-planning" | "prioritization" | "prioritization-experiment" | "product-roadmap" | "product-vision-board" | "rice" | "sailboat-retro" | "service-blueprint" | "simple-retrospective" | "sprint-planning" | "sticky-note-pack" | "swimlanes" | "team-formation-guide" | "timeline" | "timeline-workflow" | "user-story-map" | "workflow" | "vision-board" | "venn-diagram" | "storyboard" | "action-plan" | "root-cause-analysis" | "executive-summary" | "stakeholder-mapping" | "annual-calendar-2025-2026" | "health-monitor" | "okr-planning" | "swot-analysis" | "poker-planning" | "fishbone-diagram" | "risk-assessment" | "bounded-context" | "hopes-and-fears" | "swimlane-vertical";
        /**
         * If templateKey is provided, locale will decide which language the template will be created with. If locale is omitted, the user's locale will be used.
         */
        locale?: "de-DE" | "cs-CZ" | "ko-KR" | "fr-FR" | "it-IT" | "ja-JP" | "nl-NL" | "nb-NO" | "da-DK" | "sv-SE" | "fi-FI" | "ru-RU" | "pl-PL" | "tr-TR" | "hu-HU" | "en-GB" | "en-US" | "pt-BR" | "zh-CN" | "zh-TW" | "es-ES";
    };
}
export declare type CreateWhiteboardResponseOK = WhiteboardSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type CreateWhiteboardResponseError = undefined;
export interface GetWhiteboardByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard to be returned
     */
    id: number;
    /**
     * Includes collaborators on the whiteboard.
     */
    "include-collaborators"?: boolean;
    /**
     * Includes direct children of the whiteboard, as defined in the `ChildrenResponse` object.
     */
    "include-direct-children"?: boolean;
    /**
  * Includes operations associated with this whiteboard in the response, as defined in the `Operation` object.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-operations"?: boolean;
    /**
  * Includes content properties associated with this whiteboard in the response.
  The number of results will be limited to 50 and sorted in the default sort order.
  A `meta` and `_links` property will be present to indicate if more results are available and a link to retrieve the rest of the results.
  */
    "include-properties"?: boolean;
}
export declare type GetWhiteboardByIdResponseOK = WhiteboardSingleAsResponse & {
    _links?: {
        /**
         * Base url of the Confluence site.
         */
        base?: string;
    };
};
export declare type GetWhiteboardByIdResponseError = undefined;
export interface DeleteWhiteboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the whiteboard to be deleted.
     */
    id: number;
}
export declare type DeleteWhiteboardResponseOK = undefined;
export declare type DeleteWhiteboardResponseError = undefined;
//# sourceMappingURL=whiteboard.d.ts.map