/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Blob, FormData } from "@managed-api/commons-core";
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class ConfluenceCloudApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Attachment = new AttachmentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Ancestor = new AncestorGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.BlogPost = new BlogPostGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Children = new ChildrenGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Comment = new CommentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Content = new ContentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.CustomContent = new CustomContentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Label = new LabelGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Like = new LikeGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Page = new PageGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Space = new SpaceGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Task = new TaskGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Version = new VersionGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Whiteboard = new WhiteboardGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Descendant = new DescendantGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Folder = new FolderGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Database = new DatabaseGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.SmartLink = new SmartLinkGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.V1 = new V1Group(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Attachment, this.Ancestor, this.BlogPost, this.Children, this.Comment, this.Content, this.CustomContent, this.Label, this.Like, this.Page, this.Space, this.Task, this.Version, this.Whiteboard, this.Descendant, this.Folder, this.Database, this.SmartLink, this.V1);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Attachment, Ancestor, BlogPost, Children, Comment, Content, CustomContent, Label, Like, Page, Space, Task, Version, Whiteboard, Descendant, Folder, Database, SmartLink, V1) {
        this.Attachment = Attachment;
        this.Ancestor = Ancestor;
        this.BlogPost = BlogPost;
        this.Children = Children;
        this.Comment = Comment;
        this.Content = Content;
        this.CustomContent = CustomContent;
        this.Label = Label;
        this.Like = Like;
        this.Page = Page;
        this.Space = Space;
        this.Task = Task;
        this.Version = Version;
        this.Whiteboard = Whiteboard;
        this.Descendant = Descendant;
        this.Folder = Folder;
        this.Database = Database;
        this.SmartLink = SmartLink;
        this.V1 = V1;
    }
    /**
  * Returns all attachments. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the container of the attachment.
  * Alternative usage: Attachment.getAttachments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-attachments-get
  * @param options Request options.
  */
    async getAttachments(options) {
        return this.Attachment.getAttachments(options);
    }
    /**
  * Returns a specific attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment's container.
  * Alternative usage: Attachment.getAttachmentById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-attachments-id-get
  * @param options Request options.
  */
    async getAttachmentByIds(options) {
        return this.Attachment.getAttachmentById(options);
    }
    /**
  * Delete an attachment by id.
  
  Deleting an attachment moves the attachment to the trash, where it can be restored later. To permanently delete an attachment (or "purge" it),
  the endpoint must be called on a **trashed** attachment with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the container of the attachment.
  Permission to delete attachments in the space.
  Permission to administer the space (if attempting to purge).
  * Alternative usage: Attachment.deleteAttachment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-attachments-id-delete
  * @param options Request options.
  */
    async deleteAttachment(options) {
        return this.Attachment.deleteAttachment(options);
    }
    /**
  * Returns the attachments of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Alternative usage: Attachment.BlogPost.getAttachments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-blogposts-id-attachments-get
  * @param options Request options.
  */
    async getAttachmentsForBlogPost(options) {
        return this.Attachment.BlogPost.getAttachments(options);
    }
    /**
  * Returns the attachments of specific custom content. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the custom content and its corresponding space.
  * Alternative usage: Attachment.CustomContent.getAttachments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-custom-content-id-attachments-get
  * @param options Request options.
  */
    async getAttachmentsForCustomContent(options) {
        return this.Attachment.CustomContent.getAttachments(options);
    }
    /**
  * Returns the attachments of specified label. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment and its corresponding space.
  * Alternative usage: Attachment.Label.getAttachments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-labels-id-attachments-get
  * @param options Request options.
  */
    async getAttachmentsForLabel(options) {
        return this.Attachment.Label.getAttachments(options);
    }
    /**
  * Returns the attachments of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Attachment.Page.getAttachments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-pages-id-attachments-get
  * @param options Request options.
  */
    async getAttachmentsForPage(options) {
        return this.Attachment.Page.getAttachments(options);
    }
    /**
  * Returns all ancestors for a given page by ID in top-to-bottom order (that is, the highest ancestor is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Ancestor.getAllAncestorsOfPage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-pages-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfPage(options) {
        return this.Ancestor.getAllAncestorsOfPage(options);
    }
    /**
  * Returns all ancestors for a given whiteboard by ID in top-to-bottom order (that is, the highest ancestor is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the whiteboard and its corresponding space
  * Alternative usage: Ancestor.getAllAncestorsOfWhiteboard
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-whiteboards-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfWhiteboard(options) {
        return this.Ancestor.getAllAncestorsOfWhiteboard(options);
    }
    /**
  * Returns all ancestors for a given database by ID in top-to-bottom order (that is, the highest ancestor is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the database and its corresponding space
  * Alternative usage: Ancestor.getAllAncestorsOfDatabase
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-databases-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfDatabase(options) {
        return this.Ancestor.getAllAncestorsOfDatabase(options);
    }
    /**
  * Returns all ancestors for a given Smart Link in the content tree by ID in top-to-bottom order (that is, the highest ancestor is
  the first item in the response payload). The number of results is limited by the `limit` parameter and additional results
  (if available) will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get Smart Link in the content tree by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the Smart Link in the content tree and its corresponding space
  * Alternative usage: Ancestor.getAllAncestorsOfSmartLink
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-embeds-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfSmartLink(options) {
        return this.Ancestor.getAllAncestorsOfSmartLink(options);
    }
    /**
  * Returns all ancestors for a given folder by ID in top-to-bottom order (that is, the highest ancestor is
  the first item in the response payload). The number of results is limited by the `limit` parameter and additional results
  (if available) will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-folders-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the folder and its corresponding space
  * Alternative usage: Ancestor.getAllAncestorsOfFolder
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-folders-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfFolder(options) {
        return this.Ancestor.getAllAncestorsOfFolder(options);
    }
    /**
  * Returns all blog posts. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only blog posts that the user has permission to view will be returned.
  * Alternative usage: BlogPost.getBlogPosts
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-get
  * @param options Request options.
  */
    async getBlogPosts(options) {
        return this.BlogPost.getBlogPosts(options);
    }
    /**
  * Creates a new blog post in the space specified by the spaceId.
  
  By default this will create the blog post as a non-draft, unless the status is specified as draft.
  If creating a non-draft, the title must not be empty.
  
  Currently only supports the storage representation specified in the body.representation enums below
  * Alternative usage: BlogPost.createBlogPost
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-post
  * @param options Request options.
  */
    async createBlogPost(options) {
        return this.BlogPost.createBlogPost(options);
    }
    /**
  * Returns a specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space.
  * Alternative usage: BlogPost.getBlogPostById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-id-get
  * @param options Request options.
  */
    async getBlogPostById(options) {
        return this.BlogPost.getBlogPostById(options);
    }
    /**
  * Update a blog post by id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space. Permission to update blog posts in the space.
  * Alternative usage: BlogPost.updateBlogPost
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-id-put
  * @param options Request options.
  */
    async updateBlogPost(options) {
        return this.BlogPost.updateBlogPost(options);
    }
    /**
  * Delete a blog post by id.
  
  By default this will delete blog posts that are non-drafts. To delete a blog post that is a draft, the endpoint must be called on a
  draft with the following param `draft=true`. Discarded drafts are not sent to the trash and are permanently deleted.
  
  Deleting a blog post that is not a draft moves the blog post to the trash, where it can be restored later.
  To permanently delete a blog post (or "purge" it), the endpoint must be called on a **trashed** blog post with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space.
  Permission to delete blog posts in the space.
  Permission to administer the space (if attempting to purge).
  * Alternative usage: BlogPost.deleteBlogPost
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-id-delete
  * @param options Request options.
  */
    async deleteBlogPost(options) {
        return this.BlogPost.deleteBlogPost(options);
    }
    /**
  * Returns the blogposts of specified label. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: BlogPost.getBlogPostsForLabel
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-labels-id-blogposts-get
  * @param options Request options.
  */
    async getBlogPostsForLabel(options) {
        return this.BlogPost.getBlogPostsForLabel(options);
    }
    /**
  * Returns all blog posts in a space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and view the space.
  Only blog posts that the user has permission to view will be returned.
  * Alternative usage: BlogPost.getBlogPostsInSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-spaces-id-blogposts-get
  * @param options Request options.
  */
    async getBlogPostsInSpace(options) {
        return this.BlogPost.getBlogPostsInSpace(options);
    }
    /**
  * Returns all children for given whiteboard id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: Children.getWhiteboardDirectChildren
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-whiteboards-id-direct-children-get
  * @param options Request options.
  */
    async getWhiteboardDirectChildren(options) {
        return this.Children.getWhiteboardDirectChildren(options);
    }
    /**
  * Returns all children for given database id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: Children.getDatabaseDirectChildren
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-databases-id-direct-children-get
  * @param options Request options.
  */
    async getDatabaseDirectChildren(options) {
        return this.Children.getDatabaseDirectChildren(options);
    }
    /**
  * Returns all children for given smart link id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: Children.getSmartLinkDirectChildren
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-embeds-id-direct-children-get
  * @param options Request options.
  */
    async getSmartLinkDirectChildren(options) {
        return this.Children.getSmartLinkDirectChildren(options);
    }
    /**
  * Returns all children for given folder id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: Children.getFolderDirectChildren
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-folders-id-direct-children-get
  * @param options Request options.
  */
    async getFolderDirectChildren(options) {
        return this.Children.getFolderDirectChildren(options);
    }
    /**
  * Returns all child pages for given page id. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only pages that the user has permission to view will be returned.
  * Alternative usage: Children.getChildPages
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-pages-id-children-get
  * @param options Request options.
  * @deprecated
  */
    async getChildPages(options) {
        return this.Children.getChildPages(options);
    }
    /**
  * Returns all children for given page id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: Children.getPageDirectChildren
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-pages-id-direct-children-get
  * @param options Request options.
  */
    async getPageDirectChildren(options) {
        return this.Children.getPageDirectChildren(options);
    }
    /**
  * Returns all child custom content for given custom content id. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only custom content that the user has permission to view will be returned.
  * Alternative usage: Children.getChildCustomContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-custom-content-id-children-get
  * @param options Request options.
  */
    async getChildCustomContent(options) {
        return this.Children.getChildCustomContent(options);
    }
    /**
  * Returns the comments of the specific attachment.
  The number of results is limited by the `limit` parameter and additional results (if available) will be available through
  the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment and its corresponding containers.
  * Alternative usage: Comment.Attachment.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-attachments-id-footer-comments-get
  * @param options Request options.
  */
    async getAttachmentComments(options) {
        return this.Comment.Attachment.getComments(options);
    }
    /**
  * Returns the comments of the specific custom content.
  The number of results is limited by the `limit` parameter and additional results (if available) will be available through
  the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and its corresponding containers.
  * Alternative usage: Comment.CustomContent.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-custom-content-id-footer-comments-get
  * @param options Request options.
  */
    async getCustomContentComments(options) {
        return this.Comment.CustomContent.getComments(options);
    }
    /**
  * Returns all footer comments. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the container and its corresponding space.
  * Alternative usage: Comment.Footer.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-get
  * @param options Request options.
  */
    async getFooterComments(options) {
        return this.Comment.Footer.getComments(options);
    }
    /**
  * Create a footer comment.
  
  The footer comment can be made against several locations:
  - at the top level (specifying pageId or blogPostId in the request body)
  - as a reply (specifying parentCommentId in the request body)
  - against an attachment (note: this is different than the comments added via the attachment properties page on the UI, which are referred to as version comments)
  - against a custom content
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Alternative usage: Comment.Footer.createComment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-post
  * @param options Request options.
  */
    async createFooterComment(options) {
        return this.Comment.Footer.createComment(options);
    }
    /**
  * Retrieves a footer comment by id
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the container and its corresponding space.
  * Alternative usage: Comment.Footer.getCommentById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-comment-id-get
  * @param options Request options.
  */
    async getFooterCommentById(options) {
        return this.Comment.Footer.getCommentById(options);
    }
    /**
  * Update a footer comment. This can be used to update the body text of a comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Alternative usage: Comment.Footer.updateComment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-comment-id-put
  * @param options Request options.
  */
    async updateFooterComment(options) {
        return this.Comment.Footer.updateComment(options);
    }
    /**
  * Deletes a footer comment. This is a permanent deletion and cannot be reverted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to delete comments in the space.
  * Alternative usage: Comment.Footer.deleteComment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-comment-id-delete
  * @param options Request options.
  */
    async deleteFooterComment(options) {
        return this.Comment.Footer.deleteComment(options);
    }
    /**
  * Returns the children footer comments of specific comment. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Comment.Footer.getChildrenComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-id-children-get
  * @param options Request options.
  */
    async getChildrenFooterComments(options) {
        return this.Comment.Footer.getChildrenComments(options);
    }
    /**
  * Returns the root footer comments of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Comment.Footer.Page.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-pages-id-footer-comments-get
  * @param options Request options.
  */
    async getFooterCommentsForPage(options) {
        return this.Comment.Footer.Page.getComments(options);
    }
    /**
  * Returns the root footer comments of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Alternative usage: Comment.Footer.BlogPost.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-blogposts-id-footer-comments-get
  * @param options Request options.
  */
    async getFooterCommentsForBlogPost(options) {
        return this.Comment.Footer.BlogPost.getComments(options);
    }
    /**
  * Returns all inline comments. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Comment.Inline.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-get
  * @param options Request options.
  */
    async getInlineComments(options) {
        return this.Comment.Inline.getComments(options);
    }
    /**
  * Create an inline comment. This can be at the top level (specifying pageId or blogPostId in the request body)
  or as a reply (specifying parentCommentId in the request body). Note the inlineCommentProperties object in the
  request body is used to select the text the inline comment should be tied to. This is what determines the text
  highlighting when viewing a page in Confluence.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Alternative usage: Comment.Inline.createComment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-post
  * @param options Request options.
  */
    async createInlineComment(options) {
        return this.Comment.Inline.createComment(options);
    }
    /**
  * Retrieves an inline comment by id
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space.
  * Alternative usage: Comment.Inline.getCommentById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-comment-id-get
  * @param options Request options.
  */
    async getInlineCommentById(options) {
        return this.Comment.Inline.getCommentById(options);
    }
    /**
  * Update an inline comment. This can be used to update the body text of a comment and/or to resolve the comment
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Alternative usage: Comment.Inline.updateComment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-comment-id-put
  * @param options Request options.
  */
    async updateInlineComment(options) {
        return this.Comment.Inline.updateComment(options);
    }
    /**
  * Deletes an inline comment. This is a permanent deletion and cannot be reverted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to delete comments in the space.
  * Alternative usage: Comment.Inline.deleteComment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-comment-id-delete
  * @param options Request options.
  */
    async deleteInlineComment(options) {
        return this.Comment.Inline.deleteComment(options);
    }
    /**
  * Returns the children inline comments of specific comment. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Comment.Inline.getChildrenComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-id-children-get
  * @param options Request options.
  */
    async getChildrenInlineComments(options) {
        return this.Comment.Inline.getChildrenComments(options);
    }
    /**
  * Returns the root inline comments of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Comment.Inline.Page.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-pages-id-inline-comments-get
  * @param options Request options.
  */
    async getInlineCommentsForPage(options) {
        return this.Comment.Inline.Page.getComments(options);
    }
    /**
  * Returns the root inline comments of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Alternative usage: Comment.Inline.BlogPost.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-blogposts-id-inline-comments-get
  * @param options Request options.
  */
    async getInlineCommentsForFooter(options) {
        return this.Comment.Inline.BlogPost.getComments(options);
    }
    /**
  * Converts a list of content ids into their associated content types. This is useful for users migrating from v1 to v2
  who may have stored just content ids without their associated type. This will return types as they should be used in v2.
  Notably, this will return `inline-comment` for inline comments and `footer-comment` for footer comments, which is distinct from them
  both being represented by `comment` in v1.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the requested content. Any content that the user does not have permission to view or does not exist will map to `null` in the response.
  * Alternative usage: Content.convertIdsToTypes
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content/#api-group-content
  * @param options Request options.
  */
    async convertContentIdsToContentType(options) {
        return this.Content.convertIdsToTypes(options);
    }
    /**
  * Retrieves all Content Properties tied to a specified attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment.
  * Alternative usage: Content.Property.Attachment.getContentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-get
  * @param options Request options.
  */
    async getContentPropertiesForAttachment(options) {
        return this.Content.Property.Attachment.getContentProperties(options);
    }
    /**
  * Creates a new content property for an attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the attachment.
  * Alternative usage: Content.Property.Attachment.createContentProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-post
  * @param options Request options.
  */
    async createContentPropertyForAttachment(options) {
        return this.Content.Property.Attachment.createContentProperty(options);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment.
  * Alternative usage: Content.Property.Attachment.getContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyForAttachmentById(options) {
        return this.Content.Property.Attachment.getContentPropertyById(options);
    }
    /**
  * Update a content property for attachment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the attachment.
  * Alternative usage: Content.Property.Attachment.updateContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyForAttachmentById(options) {
        return this.Content.Property.Attachment.updateContentPropertyById(options);
    }
    /**
  * Deletes a content property for an attachment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to attachment the page.
  * Alternative usage: Content.Property.Attachment.deleteContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyForAttachmentById(options) {
        return this.Content.Property.Attachment.deleteContentPropertyById(options);
    }
    /**
  * Retrieves all Content Properties tied to a specified blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post.
  * Alternative usage: Content.Property.BlogPost.getContentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-get
  * @param options Request options.
  */
    async getContentPropertiesForBlogPost(options) {
        return this.Content.Property.BlogPost.getContentProperties(options);
    }
    /**
  * Creates a new property for a blogpost.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the blog post.
  * Alternative usage: Content.Property.BlogPost.createContentProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-post
  * @param options Request options.
  */
    async createContentPropertyForBlogPost(options) {
        return this.Content.Property.BlogPost.createContentProperty(options);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post.
  * Alternative usage: Content.Property.BlogPost.getContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyForBlogPostById(options) {
        return this.Content.Property.BlogPost.getContentPropertyById(options);
    }
    /**
  * Update a content property for blog post by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the blog post.
  * Alternative usage: Content.Property.BlogPost.updateContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyForBlogPostById(options) {
        return this.Content.Property.BlogPost.updateContentPropertyById(options);
    }
    /**
  * Deletes a content property for a blogpost by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the blog post.
  * Alternative usage: Content.Property.BlogPost.deleteContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyForBlogPostById(options) {
        return this.Content.Property.BlogPost.deleteContentPropertyById(options);
    }
    /**
  * Retrieves Content Properties tied to a specified custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content.
  * Alternative usage: Content.Property.CustomContent.getContentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-get
  * @param options Request options.
  */
    async getContentPropertiesForCustomContent(options) {
        return this.Content.Property.CustomContent.getContentProperties(options);
    }
    /**
  * Creates a new content property for a piece of custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the custom content.
  * Alternative usage: Content.Property.CustomContent.createContentProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-post
  * @param options Request options.
  */
    async createContentPropertyForCustomContent(options) {
        return this.Content.Property.CustomContent.createContentProperty(options);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Alternative usage: Content.Property.CustomContent.getContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyForCustomContentById(options) {
        return this.Content.Property.CustomContent.getContentPropertyById(options);
    }
    /**
  * Update a content property for a piece of custom content by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the custom content.
  * Alternative usage: Content.Property.CustomContent.updateContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        return this.Content.Property.CustomContent.updateContentPropertyById(options);
    }
    /**
  * Deletes a content property for a piece of custom content by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the custom content.
  * Alternative usage: Content.Property.CustomContent.deleteContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyForCustomContentById(options) {
        return this.Content.Property.CustomContent.deleteContentPropertyById(options);
    }
    /**
  * Retrieves Content Properties tied to a specified page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Alternative usage: Content.Property.Page.getContentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-get
  * @param options Request options.
  */
    async getContentPropertiesForPage(options) {
        return this.Content.Property.Page.getContentProperties(options);
    }
    /**
  * Creates a new content property for a page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the page.
  * Alternative usage: Content.Property.Page.createContentProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-post
  * @param options Request options.
  */
    async createContentPropertyForPage(options) {
        return this.Content.Property.Page.createContentProperty(options);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Alternative usage: Content.Property.Page.getContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyForPageById(options) {
        return this.Content.Property.Page.getContentPropertyById(options);
    }
    /**
  * Update a content property for a page by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the page.
  * Alternative usage: Content.Property.Page.updateContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyForPageById(options) {
        return this.Content.Property.Page.updateContentPropertyById(options);
    }
    /**
  * Deletes a content property for a page by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the page.
  * Alternative usage: Content.Property.Page.deleteContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyForPageById(options) {
        return this.Content.Property.Page.deleteContentPropertyById(options);
    }
    /**
  * Retrieves Content Properties attached to a specified comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the comment.
  * Alternative usage: Content.Property.Comment.getContentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-get
  * @param options Request options.
  */
    async getContentPropertiesForComment(options) {
        return this.Content.Property.Comment.getContentProperties(options);
    }
    /**
  * Creates a new content property for a comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the comment.
  * Alternative usage: Content.Property.Comment.createContentProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-post
  * @param options Request options.
  */
    async createContentPropertyForComment(options) {
        return this.Content.Property.Comment.createContentProperty(options);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the comment.
  * Alternative usage: Content.Property.Comment.getContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyForCommentById(options) {
        return this.Content.Property.Comment.getContentPropertyById(options);
    }
    /**
  * Update a content property for a comment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the comment.
  * Alternative usage: Content.Property.Comment.updateContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyForCommentById(options) {
        return this.Content.Property.Comment.updateContentPropertyById(options);
    }
    /**
  * Deletes a content property for a comment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the comment.
  * Alternative usage: Content.Property.Comment.deleteContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyForCommentById(options) {
        return this.Content.Property.Comment.deleteContentPropertyById(options);
    }
    /**
  * Retrieves Content Properties tied to a specified folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder.
  * Alternative usage: Content.Property.Folder.getContentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-id-properties-get
  * @param options Request options.
  */
    async getContentPropertiesForFolder(options) {
        return this.Content.Property.Folder.getContentProperties(options);
    }
    /**
  * Creates a new content property for a folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the folder.
  * Alternative usage: Content.Property.Folder.createContentProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-id-properties-post
  * @param options Request options.
  */
    async createContentPropertyForFolder(options) {
        return this.Content.Property.Folder.createContentProperty(options);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder.
  * Alternative usage: Content.Property.Folder.getContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-folder-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyForFolderById(options) {
        return this.Content.Property.Folder.getContentPropertyById(options);
    }
    /**
  * Update a content property for a folder by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the folder.
  * Alternative usage: Content.Property.Folder.updateContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-folder-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyForFolderById(options) {
        return this.Content.Property.Folder.updateContentPropertyById(options);
    }
    /**
  * Deletes a content property for a folder by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the folder.
  * Alternative usage: Content.Property.Folder.deleteContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-folder-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyForFolderById(options) {
        return this.Content.Property.Folder.deleteContentPropertyById(options);
    }
    /**
  * Retrieves Content Properties tied to a specified whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard.
  * Alternative usage: Content.Property.Whiteboard.getContentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-id-properties-get
  * @param options Request options.
  */
    async getContentPropertiesForWhiteboard(options) {
        return this.Content.Property.Whiteboard.getContentProperties(options);
    }
    /**
  * Creates a new content property for a whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the whiteboard.
  * Alternative usage: Content.Property.Whiteboard.createContentProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-id-properties-post
  * @param options Request options.
  */
    async createContentPropertyForWhiteboard(options) {
        return this.Content.Property.Whiteboard.createContentProperty(options);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard.
  * Alternative usage: Content.Property.Whiteboard.getContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-whiteboard-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyForWhiteboardById(options) {
        return this.Content.Property.Whiteboard.getContentPropertyById(options);
    }
    /**
  * Update a content property for a whiteboard by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the whiteboard.
  * Alternative usage: Content.Property.Whiteboard.updateContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-whiteboard-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyForWhiteboardById(options) {
        return this.Content.Property.Whiteboard.updateContentPropertyById(options);
    }
    /**
  * Deletes a content property for a whiteboard by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the whiteboard.
  * Alternative usage: Content.Property.Whiteboard.deleteContentPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-whiteboard-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyForWhiteboardById(options) {
        return this.Content.Property.Whiteboard.deleteContentPropertyById(options);
    }
    /**
  * Returns all custom content for a given type. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content, and the corresponding space (if different from the container).
  * Alternative usage: CustomContent.getCustomContentByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-blogposts-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByType(options) {
        return this.CustomContent.getCustomContentByType(options);
    }
    /**
  * Creates a new custom content in the given space, page, blogpost or other custom content.
  
  Only one of `spaceId`, `pageId`, `blogPostId`, or `customContentId` is required in the request body.
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create custom content in the space.
  * Alternative usage: CustomContent.createCustomContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-post
  * @param options Request options.
  */
    async createCustomContent(options) {
        return this.CustomContent.createCustomContent(options);
    }
    /**
  * Returns a specific piece of custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content, and the corresponding space (if different from the container).
  * Alternative usage: CustomContent.getCustomContentById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-id-get
  * @param options Request options.
  */
    async getCustomContentById(options) {
        return this.CustomContent.getCustomContentById(options);
    }
    /**
  * Update a custom content by id.
  At most one of `spaceId`, `pageId`, `blogPostId`, or `customContentId` is allowed in the request body.
  Note that if `spaceId` is specified, it must be the same as the `spaceId` used for creating the custom content
  as moving custom content to a different space is not supported.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to update custom content in the space.
  * Alternative usage: CustomContent.updateCustomContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-id-put
  * @param options Request options.
  */
    async updateCustomContent(options) {
        return this.CustomContent.updateCustomContent(options);
    }
    /**
  * Delete a custom content by id.
  
  Deleting a custom content will either move it to the trash or permanently delete it (purge it), depending on the apiSupport.
  To permanently delete a **trashed** custom content, the endpoint must be called with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space.
  Permission to delete custom content in the space.
  Permission to administer the space (if attempting to purge).
  * Alternative usage: CustomContent.deleteCustomContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-id-delete
  * @param options Request options.
  */
    async deleteCustomContent(options) {
        return this.CustomContent.deleteCustomContent(options);
    }
    /**
  * Returns all custom content for a given type within a given blogpost. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content (blog post), and the corresponding space.
  * Alternative usage: CustomContent.BlogPost.getCustomContentByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-blogposts-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByTypeInBlogPost(options) {
        return this.CustomContent.BlogPost.getCustomContentByType(options);
    }
    /**
  * Returns all custom content for a given type within a given page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content (page), and the corresponding space.
  * Alternative usage: CustomContent.Page.getCustomContentByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-pages-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByTypeInPage(options) {
        return this.CustomContent.Page.getCustomContentByType(options);
    }
    /**
  * Returns all custom content for a given type within a given space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and the corresponding space.
  * Alternative usage: CustomContent.Space.getCustomContentByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-spaces-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByTypeInSpace(options) {
        return this.CustomContent.Space.getCustomContentByType(options);
    }
    /**
  * Returns all labels. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only labels that the user has permission to view will be returned.
  * Alternative usage: Label.getLabels
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-labels-get
  * @param options Request options.
  */
    async getLabels(options) {
        return this.Label.getLabels(options);
    }
    /**
  * Returns the labels of specific attachment. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the parent content of the attachment and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Alternative usage: Label.Attachment.getLabels
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-attachments-id-labels-get
  * @param options Request options.
  */
    async getLabelsForAttachment(options) {
        return this.Label.Attachment.getLabels(options);
    }
    /**
  * Returns the labels of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Alternative usage: Label.BlogPost.getLabels
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-blogposts-id-labels-get
  * @param options Request options.
  */
    async getLabelsForBlogPost(options) {
        return this.Label.BlogPost.getLabels(options);
    }
    /**
  * Returns the labels for a specific piece of custom content. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Alternative usage: Label.CustomContent.getLabels
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-custom-content-id-labels-get
  * @param options Request options.
  */
    async getLabelsForCustomContent(options) {
        return this.Label.CustomContent.getLabels(options);
    }
    /**
  * Returns the labels of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Alternative usage: Label.Page.getLabels
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-pages-id-labels-get
  * @param options Request options.
  */
    async getLabelsForPage(options) {
        return this.Label.Page.getLabels(options);
    }
    /**
  * Returns the labels of specific space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the space.
  Only labels that the user has permission to view will be returned.
  * Alternative usage: Label.Space.getLabels
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-spaces-id-labels-get
  * @param options Request options.
  */
    async getLabelsForSpace(options) {
        return this.Label.Space.getLabels(options);
    }
    /**
  * Returns the labels of space content (pages, blogposts etc). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the space.
  Only labels that the user has permission to view will be returned.
  * Alternative usage: Label.Space.getLabelsForContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-spaces-id-content-labels-get
  * @param options Request options.
  */
    async getLabelsForSpaceContent(options) {
        return this.Label.Space.getLabelsForContent(options);
    }
    /**
  * Returns the count of likes of specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Alternative usage: Like.BlogPost.getLikeCount
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-blogposts-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCountForBlogPost(options) {
        return this.Like.BlogPost.getLikeCount(options);
    }
    /**
  * Returns the account IDs of likes of specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Alternative usage: Like.BlogPost.getAccountIdsOfLikes
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-blogposts-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikesForBlogPost(options) {
        return this.Like.BlogPost.getAccountIdsOfLikes(options);
    }
    /**
  * Returns the count of likes of specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Like.Page.getLikeCount
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-pages-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCountForPage(options) {
        return this.Like.Page.getLikeCount(options);
    }
    /**
  * Returns the account IDs of likes of specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Like.Page.getAccountIdsOfLikes
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-pages-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikesForPage(options) {
        return this.Like.Page.getAccountIdsOfLikes(options);
    }
    /**
  * Returns the count of likes of specific footer comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Alternative usage: Like.Comment.Footer.getLikeCount
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-footer-comments-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCountForFooterComment(options) {
        return this.Like.Comment.Footer.getLikeCount(options);
    }
    /**
  * Returns the account IDs of likes of specific footer comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Alternative usage: Like.Comment.Footer.getAccountIdsOfLikes
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-footer-comments-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikesForFooterComment(options) {
        return this.Like.Comment.Footer.getAccountIdsOfLikes(options);
    }
    /**
  * Returns the count of likes of specific inline comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Alternative usage: Like.Comment.Inline.getLikeCount
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-inline-comments-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCountForInlineComment(options) {
        return this.Like.Comment.Inline.getLikeCount(options);
    }
    /**
  * Returns the account IDs of likes of specific inline comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Alternative usage: Like.Comment.Inline.getAccountIdsOfLikes
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-inline-comments-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikesForInlineComment(options) {
        return this.Like.Comment.Inline.getAccountIdsOfLikes(options);
    }
    /**
  * Returns the pages of specified label. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Alternative usage: Page.getPagesForLabel
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-labels-id-pages-get
  * @param options Request options.
  */
    async getPagesForLabel(options) {
        return this.Page.getPagesForLabel(options);
    }
    /**
  * Returns all pages. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only pages that the user has permission to view will be returned.
  * Alternative usage: Page.getPages
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-get
  * @param options Request options.
  */
    async getPages(options) {
        return this.Page.getPages(options);
    }
    /**
  * Creates a page in the space.
  
  Pages are created as published by default unless specified as a draft in the status field. If creating a published page, the title must be specified.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a page in the space.
  * Alternative usage: Page.createPage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-post
  * @param options Request options.
  */
    async createPage(options) {
        return this.Page.createPage(options);
    }
    /**
  * Returns a specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space.
  * Alternative usage: Page.getPageById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get
  * @param options Request options.
  */
    async getPageById(options) {
        return this.Page.getPageById(options);
    }
    /**
  * Update a page by id.
  
  When the "current" version is updated, the provided body content is considered as the latest version. This latest body content
  will be attempted to be merged into the draft version through a content reconciliation algorithm. If two versions are significantly diverged,
  the latest provided content may entirely override what was previously in the draft.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space. Permission to update pages in the space.
  * Alternative usage: Page.updatePage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-put
  * @param options Request options.
  */
    async updatePage(options) {
        return this.Page.updatePage(options);
    }
    /**
  * Delete a page by id.
  
  By default this will delete pages that are non-drafts. To delete a page that is a draft, the endpoint must be called on a
  draft with the following param `draft=true`. Discarded drafts are not sent to the trash and are permanently deleted.
  
  Deleting a page moves the page to the trash, where it can be restored later. To permanently delete a page (or "purge" it),
  the endpoint must be called on a **trashed** page with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space.
  Permission to delete pages in the space.
  Permission to administer the space (if attempting to purge).
  * Alternative usage: Page.deletePage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-delete
  * @param options Request options.
  */
    async deletePage(options) {
        return this.Page.deletePage(options);
    }
    /**
  * Returns all pages in a space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'View' permission for the space.
  Only pages that the user has permission to view will be returned.
  * Alternative usage: Page.getPagesInSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-spaces-id-pages-get
  * @param options Request options.
  */
    async getPagesInSpace(options) {
        return this.Page.getPagesInSpace(options);
    }
    /**
  * Returns all spaces. The results will be sorted by id ascending. The number of results is limited by the `limit` parameter and
  additional results (if available) will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only spaces that the user has permission to view will be returned.
  * Alternative usage: Space.getSpaces
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space/#api-spaces-get
  * @param options Request options.
  */
    async getSpaces(options) {
        return this.Space.getSpaces(options);
    }
    /**
  * Returns a specific space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the space.
  * Alternative usage: Space.getSpaceById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space/#api-spaces-id-get
  * @param options Request options.
  */
    async getSpaceById(options) {
        return this.Space.getSpaceById(options);
    }
    /**
  * Returns all properties for the given space. Space properties are a key-value storage associated with a space.
  The limit parameter specifies the maximum number of results returned in a single response. Use the `link` response header
  to paginate through additional results.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'View' permission for the space.
  * Alternative usage: Space.Property.getProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-get
  * @param options Request options.
  */
    async getSpaceProperties(options) {
        return this.Space.Property.getProperties(options);
    }
    /**
  * Creates a new space property.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'Admin' permission for the space.
  * Alternative usage: Space.Property.createProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-post
  * @param options Request options.
  */
    async createSpacePropertyInSpace(options) {
        return this.Space.Property.createProperty(options);
    }
    /**
  * Retrieve a space property by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'View' permission for the space.
  * Alternative usage: Space.Property.getPropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-property-id-get
  * @param options Request options.
  */
    async getSpacePropertyById(options) {
        return this.Space.Property.getPropertyById(options);
    }
    /**
  * Update a space property by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'Admin' permission for the space.
  * Alternative usage: Space.Property.updatePropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-property-id-put
  * @param options Request options.
  */
    async updateSpacePropertyById(options) {
        return this.Space.Property.updatePropertyById(options);
    }
    /**
  * Deletes a space property by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'Admin' permission for the space.
  * Alternative usage: Space.Property.deletePropertyById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteSpacePropertyById(options) {
        return this.Space.Property.deletePropertyById(options);
    }
    /**
  * Returns all tasks. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only tasks that the user has permission to view will be returned.
  * Alternative usage: Task.getTasks
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-task/#api-tasks-get
  * @param options Request options.
  */
    async getTasks(options) {
        return this.Task.getTasks(options);
    }
    /**
  * Returns a specific task.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the containing page or blog post and its corresponding space.
  * Alternative usage: Task.getTaskById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-task/#api-tasks-id-get
  * @param options Request options.
  */
    async getTaskById(options) {
        return this.Task.getTaskById(options);
    }
    /**
  * Update a task by id. This endpoint currently only supports updating task status.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the containing page or blog post and view its corresponding space.
  * Alternative usage: Task.updateTask
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-task/#api-tasks-id-get
  * @param options Request options.
  */
    async updateTask(options) {
        return this.Task.updateTask(options);
    }
    /**
  * Returns the versions of specific attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment and its corresponding space.
  * Alternative usage: Version.Attachment.getVersions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-attachments-id-versions-get
  * @param options Request options.
  */
    async getAttachmentVersions(options) {
        return this.Version.Attachment.getVersions(options);
    }
    /**
  * Retrieves version details for the specified attachment and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment.
  * Alternative usage: Version.Attachment.getVersionDetails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-attachments-attachment-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetailsForAttachmentVersion(options) {
        return this.Version.Attachment.getVersionDetails(options);
    }
    /**
  * Returns the versions of specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space.
  * Alternative usage: Version.BlogPost.getVersions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-blogposts-id-versions-get
  * @param options Request options.
  */
    async getBlogPostVersions(options) {
        return this.Version.BlogPost.getVersions(options);
    }
    /**
  * Retrieves version details for the specified blog post and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post.
  * Alternative usage: Version.BlogPost.getVersionDetails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-blogposts-blogpost-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetailsForBlogPostVersion(options) {
        return this.Version.BlogPost.getVersionDetails(options);
    }
    /**
  * Returns the versions of specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space.
  * Alternative usage: Version.Page.getVersions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-pages-id-versions-get
  * @param options Request options.
  */
    async getPageVersions(options) {
        return this.Version.Page.getVersions(options);
    }
    /**
  * Retrieves version details for the specified page and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Alternative usage: Version.Page.getVersionDetails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-pages-page-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetailsForPageVersion(options) {
        return this.Version.Page.getVersionDetails(options);
    }
    /**
  * Returns the versions of specific custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and its corresponding page and space.
  * Alternative usage: Version.CustomContent.getVersions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-custom-content-custom-content-id-versions-get
  * @param options Request options.
  */
    async getCustomContentVersions(options) {
        return this.Version.CustomContent.getVersions(options);
    }
    /**
  * Retrieves version details for the specified custom content and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Alternative usage: Version.CustomContent.getVersionDetails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-custom-content-custom-content-id-versions-get
  * @param options Request options.
  */
    async getVersionDetailsForCustomContentVersion(options) {
        return this.Version.CustomContent.getVersionDetails(options);
    }
    /**
  * Retrieves the versions of the specified footer comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Alternative usage: Version.Comment.Footer.getVersions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-footer-comments-id-versions-get
  * @param options Request options.
  */
    async getFooterCommentVersions(options) {
        return this.Version.Comment.Footer.getVersions(options);
    }
    /**
  * Retrieves version details for the specified footer comment version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Alternative usage: Version.Comment.Footer.getVersionDetails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-footer-comments-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetailsForFooterCommentVersion(options) {
        return this.Version.Comment.Footer.getVersionDetails(options);
    }
    /**
  * Retrieves the versions of the specified inline comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Alternative usage: Version.Comment.Inline.getVersions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-inline-comments-id-versions-get
  * @param options Request options.
  */
    async getInlineCommentVersions(options) {
        return this.Version.Comment.Inline.getVersions(options);
    }
    /**
  * Retrieves version details for the specified inline comment version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Alternative usage: Version.Comment.Inline.getVersionDetails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-inline-comments-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetailsForInlineCommentVersion(options) {
        return this.Version.Comment.Inline.getVersionDetails(options);
    }
    /**
  * Creates a whiteboard in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a whiteboard in the space.
  * Alternative usage: Whiteboard.createWhiteboard
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-post
  * @param options Request options.
  */
    async createWhiteboard(options) {
        return this.Whiteboard.createWhiteboard(options);
    }
    /**
  * Returns a specific whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard and its corresponding space.
  * Alternative usage: Whiteboard.getWhiteboardById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get
  * @param options Request options.
  */
    async getWhiteboardById(options) {
        return this.Whiteboard.getWhiteboardById(options);
    }
    /**
  * Delete a whiteboard by id.
  
  Deleting a whiteboard moves the whiteboard to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard and its corresponding space.
  Permission to delete whiteboards in the space.
  * Alternative usage: Whiteboard.deleteWhiteboard
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-delete
  * @param options Request options.
  */
    async deleteWhiteboard(options) {
        return this.Whiteboard.deleteWhiteboard(options);
    }
    /**
  * Returns descendants in the content tree for a given whiteboard by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the whiteboard and its corresponding space
  * Alternative usage: Descendant.getWhiteboardDescendants
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-whiteboards-id-descendants-get
  * @param options Request options.
  */
    async getWhiteboardDescendants(options) {
        return this.Descendant.getWhiteboardDescendants(options);
    }
    /**
  * Returns descendants in the content tree for a given database by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the database and its corresponding space
  * Alternative usage: Descendant.getDatabaseDescendants
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-databases-id-descendants-get
  * @param options Request options.
  */
    async getDatabaseDescendants(options) {
        return this.Descendant.getDatabaseDescendants(options);
    }
    /**
  * Returns descendants in the content tree for a given smart link by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the smart link and its corresponding space
  * Alternative usage: Descendant.getSmartLinkDescendants
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-embeds-id-descendants-get
  * @param options Request options.
  */
    async getSmartLinkDescendants(options) {
        return this.Descendant.getSmartLinkDescendants(options);
    }
    /**
  * Returns descendants in the content tree for a given folder by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the  and its corresponding space
  * Alternative usage: Descendant.getFolderDescendants
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-folders-id-descendants-get
  * @param options Request options.
  */
    async getFolderDescendants(options) {
        return this.Descendant.getFolderDescendants(options);
    }
    /**
  * Returns descendants in the content tree for a given page by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the page and its corresponding space
  * Alternative usage: Descendant.getPageDescendants
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-pages-id-descendants-get
  * @param options Request options.
  */
    async getPageDescendants(options) {
        return this.Descendant.getPageDescendants(options);
    }
    /**
  * Creates a folder in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a folder in the space.
  * Alternative usage: Folder.createFolder
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-post
  * @param options Request options.
  */
    async createFolder(options) {
        return this.Folder.createFolder(options);
    }
    /**
  * Returns a specific folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder and its corresponding space.
  * Alternative usage: Folder.getFolderById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get
  * @param options Request options.
  */
    async getFolderById(options) {
        return this.Folder.getFolderById(options);
    }
    /**
  * Delete a folder by id.
  
  Deleting a folder moves the folder to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder and its corresponding space.
  Permission to delete folders in the space.
  * Alternative usage: Folder.deleteFolder
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-delete
  * @param options Request options.
  */
    async deleteFolder(options) {
        return this.Folder.deleteFolder(options);
    }
    /**
  * Creates a database in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a database in the space.
  * Alternative usage: Database.createDatabase
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-post
  * @param options Request options.
  */
    async createDatabase(options) {
        return this.Database.createDatabase(options);
    }
    /**
  * Returns a specific database.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the database and its corresponding space.
  * Alternative usage: Database.getDatabaseById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get
  * @param options Request options.
  */
    async getDatabaseById(options) {
        return this.Database.getDatabaseById(options);
    }
    /**
  * Delete a database by id.
  
  Deleting a database moves the database to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the database and its corresponding space.
  Permission to delete databases in the space.
  * Alternative usage: Database.deleteDatabase
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-delete
  * @param options Request options.
  */
    async deleteDatabase(options) {
        return this.Database.deleteDatabase(options);
    }
    /**
  * Creates a Smart Link in the content tree in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a Smart Link in the content tree in the space.
  * Alternative usage: SmartLink.createSmartLink
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-post
  * @param options Request options.
  */
    async createSmartLink(options) {
        return this.SmartLink.createSmartLink(options);
    }
    /**
  * Returns a specific Smart Link in the content tree.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the Smart Link in the content tree and its corresponding space.
  * Alternative usage: SmartLink.getSmartLinkById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get
  * @param options Request options.
  */
    async getSmartLinkById(options) {
        return this.SmartLink.getSmartLinkById(options);
    }
    /**
  * Delete a Smart Link in the content tree by id.
  
  Deleting a Smart Link in the content tree moves the Smart Link to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the Smart Link in the content tree and its corresponding space.
  Permission to delete Smart Links in the content tree in the space.
  * Alternative usage: SmartLink.deleteSmartLink
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-delete
  * @param options Request options.
  */
    async deleteSmartLink(options) {
        return this.SmartLink.deleteSmartLink(options);
    }
    /**
  * Publishes a shared draft of a page created from a blueprint.
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Alternative usage: V1.Content.publishSharedDraft
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-put
  * @param options Request options.
  */
    async publishSharedDraft(options) {
        return this.V1.Content.publishSharedDraft(options);
    }
    /**
  * Publishes a legacy draft of a page created from a blueprint. Legacy drafts
  will eventually be removed in favor of shared drafts. For now, this method
  works the same as [Publish shared draft](#api-content-blueprint-instance-draftId-put).
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Alternative usage: V1.Content.publishLegacyDraft
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-post
  * @param options Request options.
  */
    async publishLegacyDraft(options) {
        return this.V1.Content.publishLegacyDraft(options);
    }
    /**
  * Returns the list of content that matches a Confluence Query Language
  (CQL) query. For information on CQL, see:
  [Advanced searching using CQL](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Example initial call:
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: V1.Content.searchContentByCQL
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-search-get
  * @param options Request options.
  */
    async searchContentByCql(options) {
        return this.V1.Content.searchContentByCql(options);
    }
    /**
  * Adds an attachment to a piece of content. If the attachment already exists
  for the content, then the attachment is updated (i.e. a new version of the
  attachment is created).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a piece of
  content (id='123') with a comment and `minorEdits`=true. If the 'example.txt'
  file already exists, it will update it with a new version of the attachment.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X PUT \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Attachment.createOrUpdateAttachment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-put
  * @param options Request options.
  */
    async createOrUpdateContentAttachment(options) {
        return this.V1.Content.Attachment.createOrUpdateAttachment(options);
    }
    /**
  * Adds an attachment to a piece of content. This method only adds a new
  attachment. If you want to update an existing attachment, use
  [Create or update attachments](#api-content-id-child-attachment-put).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a container
  (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Attachment.createAttachment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-post
  * @param options Request options.
  */
    async createContentAttachment(options) {
        return this.V1.Content.Attachment.createAttachment(options);
    }
    /**
  * Updates the attachment properties, i.e. the non-binary data of an attachment
  like the filename, media-type, comment, and parent container.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Attachment.updateAttachmentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-put
  * @param options Request options.
  */
    async updateContentAttachmentProperties(options) {
        return this.V1.Content.Attachment.updateAttachmentProperties(options);
    }
    /**
  * Updates the binary data of an attachment, given the attachment ID, and
  optionally the comment and the minor edit field.
  
  This method is essentially the same as [Create or update attachments](#api-content-id-child-attachment-put),
  except that it matches the attachment ID rather than the name.
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command updates an attachment (id='att456') that is attached
  to a piece of content (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment/att456/data
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Attachment.updateAttachmentData
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-data-post
  * @param options Request options.
  */
    async updateContentAttachmentData(options) {
        return this.V1.Content.Attachment.updateAttachmentData(options);
    }
    /**
  * Deprecated, use the [single asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post)
  or the [bulk asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-bulk-tasks-post) instead.
  
  Converts a content body from one format to another format.
  
  Supported conversions:
  
  - storage: view, export_view, styled_view, editor
  - editor: storage
  - view: none
  - export_view: none
  - styled_view: none
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Alternative usage: V1.Content.Body.convertBody
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-to-post
  * @param options Request options.
  * @deprecated
  */
    async convertContentBody(options) {
        return this.V1.Content.Body.convertBody(options);
    }
    /**
  * Converts a content body from one format to another format asynchronously.
  Returns the asyncId for the asynchronous task.
  
  Supported conversions:
  
  - atlas_doc_format: editor, export_view, storage, styled_view, view
  - storage: atlas_doc_format, editor, export_view, styled_view, view
  - editor: storage
  
  No other conversions are supported at the moment.
  Once a conversion is completed, it will be available for 5 minutes at the result endpoint.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Alternative usage: V1.Content.Body.asyncConvertBody
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post
  * @param options Request options.
  */
    async asyncConvertContentBody(options) {
        return this.V1.Content.Body.asyncConvertBody(options);
    }
    /**
  * Returns the asynchronous content body for the corresponding id if the task is complete
  or returns the status of the task.
  
  After the task is completed, the result can be obtained for 5 minutes, or until an identical conversion request is made again,
  with allowCache query param set to false.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Alternative usage: V1.Content.Body.getAsyncConvertResult
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-id-get
  * @param options Request options.
  */
    async getAsyncConvertContentBodyResult(options) {
        return this.V1.Content.Body.getAsyncConvertResult(options);
    }
    /**
  * Returns the body of a macro in storage format, for the given macro ID.
  This includes information like the name of the macro, the body of the macro,
  and any macro parameters. This method is mainly used by Cloud apps.
  
  About the macro ID: When a macro is created in a new version of content,
  Confluence will generate a random ID for it, unless an ID is specified
  (by an app). The macro ID will look similar to this: '50884bd9-0cb8-41d5-98be-f80943c14f96'.
  The ID is then persisted as new versions of content are created, and is
  only modified by Confluence if there are conflicting IDs.
  
  For Forge macros, the value for macro ID is the "local ID" of that particular ADF node.
  This value can be retrieved either client-side by calling view.getContext() and accessing "localId"
  on the resulting object, or server-side by examining the "local-id" parameter node inside the "parameters" node.
  
  Note that there are other attributes named "local-id", but only this particular one is used to store the macro ID.
  
  Example:
  <ac:adf-node type="extension">
    <ac:adf-attribute key="extension-type">com.atlassian.ecosystem</ac:adf-attribute>
    <ac:adf-attribute key="parameters">
        <ac:adf-parameter key="local-id">e9c4aa10-73fa-417c-888d-48c719ae4165</ac:adf-parameter>
    </ac:adf-parameter>
  </ac:adf-node>
  
  Note, to preserve backwards compatibility this resource will also match on
  the hash of the macro body, even if a macro ID is found. This check will
  eventually become redundant, as macro IDs are generated for pages and
  transparently propagate out to all instances.
  
  This backwards compatibility logic does not apply to Forge macros; those
  can only be retrieved by their ID.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content that the macro is in.
  * Alternative usage: V1.Content.Body.Macro.getMacroById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---macro-body/#api-wiki-rest-api-content-id-history-version-macro-id-macroid-get
  * @param options Request options.
  */
    async getMacroBodyById(options) {
        return this.V1.Content.Body.Macro.getMacroById(options);
    }
    /**
  * Move a page to a new location relative to a target page:
  
  * `before` - move the page under the same parent as the target, before the target in the list of children
  * `after` - move the page under the same parent as the target, after the target in the list of children
  * `append` - move the page to be a child of the target
  
  Caution: This API can move pages to the top level of a space. Top-level pages are difficult to find in the UI
  because they do not show up in the page tree display. To avoid this, never use `before` or `after` positions
  when the `targetId` is a top-level page.
  * Alternative usage: V1.Content.Move.movePageToNewLocationRelativeToTargetPage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-pageid-move-position-targetid-put
  * @param options Request options.
  */
    async movePageToNewLocationRelativeToTargetPage(options) {
        return this.V1.Content.Move.movePageToNewLocationRelativeToTargetPage(options);
    }
    /**
  * Returns a map of the descendants of a piece of content. This is similar
  to [Get content children](#api-content-id-child-get), except that this
  method returns child pages at all levels, rather than just the direct
  child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  The map will always include all descendant types that are valid for the content.
  However, if the content has no instances of a descendant type, the map will
  contain an empty array for that descendant type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Alternative usage: V1.Content.Descendant.getDescendants
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-get
  * @param options Request options.
  * @deprecated
  */
    async getContentDescendants(options) {
        return this.V1.Content.Descendant.getDescendants(options);
    }
    /**
  * Returns all descendants of a given type, for a piece of content. This is
  similar to [Get content children by type](#api-content-id-child-type-get),
  except that this method returns child pages at all levels, rather than just
  the direct child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  Custom content types that are provided by apps can also be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Alternative usage: V1.Content.Descendant.getDescendantsByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-type-get
  * @param options Request options.
  * @deprecated
  */
    async getContentDescendantsByType(options) {
        return this.V1.Content.Descendant.getDescendantsByType(options);
    }
    /**
  * Copy page hierarchy allows the copying of an entire hierarchy of pages and their associated properties, permissions and attachments.
   The id path parameter refers to the content id of the page to copy, and the new parent of this copied page is defined using the destinationPageId in the request body.
   The titleOptions object defines the rules of renaming page titles during the copy;
   for example, search and replace can be used in conjunction to rewrite the copied page titles.
  
   Response example:
   <pre><code>
   {
        "id" : "1180606",
        "links" : {
             "status" : "/rest/api/longtask/1180606"
        }
   }
   </code></pre>
   Use the /longtask/<taskId> REST API to get the copy task status.
  * Alternative usage: V1.Content.Copy.copyPageHierarchy
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-pagehierarchy-copy-post
  * @param options Request options.
  */
    async copyPageHierarchy(options) {
        return this.V1.Content.Copy.copyPageHierarchy(options);
    }
    /**
  * Copies a single page and its associated properties, permissions, attachments, and custom contents.
   The `id` path parameter refers to the content ID of the page to copy. The target of the page to be copied
   is defined using the `destination` in the request body and can be one of the following types.
  
    - `space`: page will be copied to the specified space as a root page on the space
    - `parent_page`: page will be copied as a child of the specified parent page
    - `existing_page`: page will be copied and replace the specified page
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Add' permission for the space that the content will be copied in and permission to update the content if copying to an `existing_page`.
  * Alternative usage: V1.Content.Copy.copySinglePage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-copy-post
  * @param options Request options.
  */
    async copySinglePage(options) {
        return this.V1.Content.Copy.copySinglePage(options);
    }
    /**
  * Adds labels to a piece of content. Does not modify the existing labels.
  
  Notes:
  
  - Labels can also be added when creating content ([Create content](#api-content-post)).
  - Labels can be updated when updating content ([Update content](#api-content-id-put)).
  This will delete the existing labels and replace them with the labels in
  the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Label.addLabel
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-post
  * @param options Request options.
  */
    async addContentLabel(options) {
        return this.V1.Content.Label.addLabel(options);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content](#api-content-id-label-label-delete)
  except that the label name is specified via a query parameter.
  
  Use this method if the label name has "/" characters, as
  [Remove label from content using query parameter](#api-content-id-label-delete)
  does not accept "/" characters for the label name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Label.removeLabelWithQueryParameter
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-delete
  * @param options Request options.
  */
    async removeContentLabelWithQueryParameter(options) {
        return this.V1.Content.Label.removeLabelWithQueryParameter(options);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content using query parameter](#api-content-id-label-delete)
  except that the label name is specified via a path parameter.
  
  Use this method if the label name does not have "/" characters, as the path
  parameter does not accept "/" characters for security reasons. Otherwise,
  use [Remove label from content using query parameter](#api-content-id-label-delete).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Label.removeLabel
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-label-delete
  * @param options Request options.
  */
    async removeContentLabel(options) {
        return this.V1.Content.Label.removeLabel(options);
    }
    /**
  * Returns the restrictions on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: V1.Content.Restriction.getRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-get
  * @param options Request options.
  */
    async getContentRestrictions(options) {
        return this.V1.Content.Restriction.getRestrictions(options);
    }
    /**
  * Updates restrictions for a piece of content. This removes the existing
  restrictions and replaces them with the restrictions in the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: V1.Content.Restriction.updateRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-put
  * @param options Request options.
  */
    async updateContentRestrictions(options) {
        return this.V1.Content.Restriction.updateRestrictions(options);
    }
    /**
  * Adds restrictions to a piece of content. Note, this does not change any
  existing restrictions on the content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: V1.Content.Restriction.addRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-post
  * @param options Request options.
  */
    async addContentRestrictions(options) {
        return this.V1.Content.Restriction.addRestrictions(options);
    }
    /**
  * Removes all restrictions (read and update) on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: V1.Content.Restriction.deleteRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-delete
  * @param options Request options.
  */
    async deleteContentRestrictions(options) {
        return this.V1.Content.Restriction.deleteRestrictions(options);
    }
    /**
  * Returns restrictions on a piece of content by operation. This method is
  similar to [Get restrictions](#api-content-id-restriction-get) except that
  the operations are properties of the return object, rather than items in
  a results array.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: V1.Content.Restriction.getRestrictionsByOperation
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-get
  * @param options Request options.
  */
    async getContentRestrictionsByOperation(options) {
        return this.V1.Content.Restriction.getRestrictionsByOperation(options);
    }
    /**
  * Returns the restictions on a piece of content for a given operation (read
  or update).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: V1.Content.Restriction.getRestrictionsForOperation
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-get
  * @param options Request options.
  */
    async getContentRestrictionsForOperation(options) {
        return this.V1.Content.Restriction.getRestrictionsForOperation(options);
    }
    /**
  * Returns whether the specified content restriction applies to a group.
  For example, if a page with `id=123` has a `read` restriction for the `123456` group id,
  the following request will return `true`:
  
  `/wiki/rest/api/content/123/restriction/byOperation/read/byGroupId/123456`
  
  Note that a response of `true` does not guarantee that the group can view the page, as it does not account for
  account-inherited restrictions, space permissions, or even product access. For more
  information, see [Confluence permissions](https://confluence.atlassian.com/x/_AozKw).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: V1.Content.Restriction.Group.getGroupStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-get
  * @param options Request options.
  */
    async getContentRestrictionGroupStatus(options) {
        return this.V1.Content.Restriction.Group.getGroupStatus(options);
    }
    /**
  * Adds a group to a content restriction by Group Id. That is, grant read or update
  permission to the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: V1.Content.Restriction.Group.addGroup
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-put
  * @param options Request options.
  */
    async addContentRestrictionGroup(options) {
        return this.V1.Content.Restriction.Group.addGroup(options);
    }
    /**
  * Removes a group from a content restriction. That is, remove read or update
  permission for the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: V1.Content.Restriction.Group.removeGroup
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-delete
  * @param options Request options.
  */
    async removeContentRestrictionGroup(options) {
        return this.V1.Content.Restriction.Group.removeGroup(options);
    }
    /**
  * Restores a historical version to be the latest version. That is, a new version
  is created with the content of the historical version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Version.restoreVersion
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-post
  * @param options Request options.
  */
    async restoreContentVersion(options) {
        return this.V1.Content.Version.restoreVersion(options);
    }
    /**
  * Delete a historical version. This does not delete the changes made to the
  content in that version, rather the changes for the deleted version are
  rolled up into the next version. Note, you cannot delete the current version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: V1.Content.Version.deleteVersion
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-versionnumber-delete
  * @param options Request options.
  */
    async deleteContentVersion(options) {
        return this.V1.Content.Version.deleteVersion(options);
    }
    /**
  * Returns the watches for a page. A user that watches a page will receive
  receive notifications when the page is updated.
  
  If you want to manage watches for a page, use the following `user` methods:
  
  - [Get content watch status for user](#api-user-watch-content-contentId-get)
  - [Add content watch](#api-user-watch-content-contentId-post)
  - [Remove content watch](#api-user-watch-content-contentId-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.getWatchesForPage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-child-created-get
  * @param options Request options.
  */
    async getWatchesForPage(options) {
        return this.V1.Watcher.getWatchesForPage(options);
    }
    /**
  * Returns all space watches for the space that the content is in. A user that
  watches a space will receive receive notifications when any content in the
  space is updated.
  
  If you want to manage watches for a space, use the following `user` methods:
  
  - [Get space watch status for user](#api-user-watch-space-spaceKey-get)
  - [Add space watch](#api-user-watch-space-spaceKey-post)
  - [Remove space watch](#api-user-watch-space-spaceKey-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.getWatchesForSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-created-get
  * @param options Request options.
  */
    async getWatchesForSpace(options) {
        return this.V1.Watcher.getWatchesForSpace(options);
    }
    /**
     * Returns a list of watchers of a space
     * Alternative usage: V1.Watcher.getSpaceWatchers
     * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-space-spacekey-watch-get
     * @param options Request options.
     */
    async getSpaceWatchers(options) {
        return this.V1.Watcher.getSpaceWatchers(options);
    }
    /**
  * Returns whether a user is watching a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Content.getWatcherStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-get
  * @param options Request options.
  */
    async getContentWatcherStatus(options) {
        return this.V1.Watcher.Content.getWatcherStatus(options);
    }
    /**
  * Adds a user as a watcher to a piece of content. Choose the user by doing
  one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Content.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-post
  * @param options Request options.
  */
    async addContentWatcher(options) {
        return this.V1.Watcher.Content.addWatcher(options);
    }
    /**
  * Removes a user as a watcher from a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Content.removeWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-delete
  * @param options Request options.
  */
    async removeContentWatcher(options) {
        return this.V1.Watcher.Content.removeWatcher(options);
    }
    /**
  * Returns whether a user is watching a label. Choose the user by doing one
  of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Label.getWatcherStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-get
  * @param options Request options.
  */
    async getLabelWatcherStatus(options) {
        return this.V1.Watcher.Label.getWatcherStatus(options);
    }
    /**
  * Adds a user as a watcher to a label. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Label.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-post
  * @param options Request options.
  */
    async addLabelWatcher(options) {
        return this.V1.Watcher.Label.addWatcher(options);
    }
    /**
  * Removes a user as a watcher from a label. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Label.removeWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-delete
  * @param options Request options.
  */
    async removeLabelWatcher(options) {
        return this.V1.Watcher.Label.removeWatcher(options);
    }
    /**
  * Returns whether a user is watching a space. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Space.getWatcherStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-get
  * @param options Request options.
  */
    async getSpaceWatcherStatus(options) {
        return this.V1.Watcher.Space.getWatcherStatus(options);
    }
    /**
  * Adds a user as a watcher to a space. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Space.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-post
  * @param options Request options.
  */
    async addSpaceWatcher(options) {
        return this.V1.Watcher.Space.addWatcher(options);
    }
    /**
  * Removes a user as a watcher from a space. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Watcher.Space.removeWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-delete
  * @param options Request options.
  */
    async removeSpaceWatcher(options) {
        return this.V1.Watcher.Space.removeWatcher(options);
    }
    /**
  * Returns all user groups. The returned groups are ordered alphabetically in
  ascending order by group name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.UserGroup.getUserGroups
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-get
  * @param options Request options.
  */
    async getUserGroups(options) {
        return this.V1.UserGroup.getUserGroups(options);
    }
    /**
  * Creates a new user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: V1.UserGroup.createUserGroup
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-post
  * @param options Request options.
  */
    async createUserGroup(options) {
        return this.V1.UserGroup.createUserGroup(options);
    }
    /**
  * Delete user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: V1.UserGroup.deleteUserGroupById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-delete
  * @param options Request options.
  */
    async deleteUserGroupById(options) {
        return this.V1.UserGroup.deleteUserGroupById(options);
    }
    /**
  * Returns a user group for a given group id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.UserGroup.getUserGroupById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-get
  * @param options Request options.
  */
    async getUserGroupById(options) {
        return this.V1.UserGroup.getUserGroupById(options);
    }
    /**
  * Adds a user as a member in a group represented by its groupId
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: V1.UserGroup.Member.addMemberById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-post
  * @param options Request options.
  */
    async addUserGroupMembersById(options) {
        return this.V1.UserGroup.Member.addMemberById(options);
    }
    /**
  * Remove user as a member from a group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: V1.UserGroup.Member.removeMemberById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-delete
  * @param options Request options.
  */
    async removeUserGroupMembersById(options) {
        return this.V1.UserGroup.Member.removeMemberById(options);
    }
    /**
  * Returns the users that are members of a group.
  
  Use updated Get group API
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.UserGroup.Member.getMembersById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-groupid-membersbygroupid-get
  * @param options Request options.
  */
    async getUserGroupMembersById(options) {
        return this.V1.UserGroup.Member.getMembersById(options);
    }
    /**
  * Returns label information and a list of contents associated with the label.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission). Only contents
  that the user is permitted to view is returned.
  * Alternative usage: V1.Label.getInfo
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-label-info/#api-wiki-rest-api-label-get
  * @param options Request options.
  */
    async getLabelInfo(options) {
        return this.V1.Label.getInfo(options);
    }
    /**
  * Returns information about all active long-running tasks (e.g. space export),
  such as how long each task has been running and the percentage of each task
  that has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.LongRunningTask.getLongRunningTasks
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-get
  * @param options Request options.
  */
    async getLongRunningTasks(options) {
        return this.V1.LongRunningTask.getLongRunningTasks(options);
    }
    /**
  * Returns information about an active long-running task (e.g. space export),
  such as how long it has been running and the percentage of the task that
  has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.LongRunningTask.getLongRunningTask
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-id-get
  * @param options Request options.
  */
    async getLongRunningTask(options) {
        return this.V1.LongRunningTask.getLongRunningTask(options);
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all content that the current user
  has an 'ignore' relationship with:
  `GET /wiki/rest/api/relation/ignore/from/user/current/to/content`
  Note, 'ignore' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Alternative usage: V1.Relation.findTargetEntitiesRelatedToSourceEntity
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-get
  * @param options Request options.
  */
    async findTargetEntitiesRelatedToSourceEntity(options) {
        return this.V1.Relation.findTargetEntitiesRelatedToSourceEntity(options);
    }
    /**
  * Find whether a particular type of relationship exists from a source
  entity to a target entity. Note, relationships are one way.
  
  For example, you can use this method to find whether the current user has
  selected a particular page as a favorite (i.e. 'save for later'):
  `GET /wiki/rest/api/relation/favourite/from/user/current/to/content/123`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Alternative usage: V1.Relation.findRelationshipFromSourceToTarget
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-get
  * @param options Request options.
  */
    async findRelationshipFromSourceToTarget(options) {
        return this.V1.Relation.findRelationshipFromSourceToTarget(options);
    }
    /**
  * Creates a relationship between two entities (user, space, content). The
  'favourite' relationship is supported by default, but you can use this method
  to create any type of relationship between two entities.
  
  For example, the following method creates a 'sibling' relationship between
  two pieces of content:
  `PUT /wiki/rest/api/relation/sibling/from/content/123/to/content/456`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Relation.createRelationship
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-put
  * @param options Request options.
  */
    async createRelationship(options) {
        return this.V1.Relation.createRelationship(options);
    }
    /**
  * Deletes a relationship between two entities (user, space, content).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  For favourite relationships, the current user can only delete their own
  favourite relationships. A space administrator can delete favourite
  relationships for any user.
  * Alternative usage: V1.Relation.deleteRelationship
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-delete
  * @param options Request options.
  */
    async deleteRelationship(options) {
        return this.V1.Relation.deleteRelationship(options);
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all users that have a 'collaborator'
  relationship to a piece of content with an ID of '1234':
  `GET /wiki/rest/api/relation/collaborator/to/content/1234/from/user`
  Note, 'collaborator' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Alternative usage: V1.Relation.findSourceEntitiesRelatedToTargetEntity
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-to-targettype-targetkey-from-sourcetype-get
  * @param options Request options.
  */
    async findSourceEntitiesRelatedToTargetEntity(options) {
        return this.V1.Relation.findSourceEntitiesRelatedToTargetEntity(options);
    }
    /**
  * Searches for content using the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  **Note that CQL input queries submitted through the `/wiki/rest/api/search` endpoint no longer support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.**
  See this [deprecation notice](https://developer.atlassian.com/cloud/confluence/deprecation-notice-search-api/) for more details.
  
  Example initial call:
  ```
  /wiki/rest/api/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the entities. Note, only entities that the user has
  permission to view will be returned.
  * Alternative usage: V1.Search.searchContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-get
  * @param options Request options.
  */
    async searchContent(options) {
        return this.V1.Search.searchContent(options);
    }
    /**
  * Searches for users using user-specific queries from the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Note that CQL input queries submitted through the `/wiki/rest/api/search/user` endpoint only support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.
  
  Note that some user fields may be set to null depending on the user's privacy settings.
  These are: email, profilePicture, displayName, and timeZone.
  * Alternative usage: V1.Search.searchUsers
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-user-get
  * @param options Request options.
  */
    async searchUsers(options) {
        return this.V1.Search.searchUsers(options);
    }
    /**
  * Returns the look and feel settings for the site or a single space. This
  includes attributes such as the color scheme, padding, and border radius.
  
  The look and feel settings for a space can be inherited from the global
  look and feel settings or provided by a theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  None
  * Alternative usage: V1.Setting.getLookAndFeelSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-get
  * @param options Request options.
  */
    async getLookAndFeelSettings(options) {
        return this.V1.Setting.getLookAndFeelSettings(options);
    }
    /**
  * Updates the look and feel settings for the site or for a single space.
  If custom settings exist, they are updated. If no custom settings exist,
  then a set of custom settings is created.
  
  Note, if a theme is selected for a space, the space look and feel settings
  are provided by the theme and cannot be overridden.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: V1.Setting.updateLookAndFeelSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-post
  * @param options Request options.
  */
    async updateLookAndFeelSettings(options) {
        return this.V1.Setting.updateLookAndFeelSettings(options);
    }
    /**
  * Resets the custom look and feel settings for the site or a single space.
  This changes the values of the custom settings to be the same as the
  default settings. It does not change which settings (default or custom)
  are selected. Note, the default space settings are inherited from the
  current global settings.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: V1.Setting.resetLookAndFeelSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-delete
  * @param options Request options.
  */
    async resetLookAndFeelSettings(options) {
        return this.V1.Setting.resetLookAndFeelSettings(options);
    }
    /**
  * Returns the system information for the Confluence Cloud tenant. This
  information is used by Atlassian.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.Setting.getSystemInfo
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-systeminfo-get
  * @param options Request options.
  */
    async getSystemInfo(options) {
        return this.V1.Setting.getSystemInfo(options);
    }
    /**
  * Creates a new space. Note, currently you cannot set space labels when
  creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Alternative usage: V1.Space.createSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-post
  * @param options Request options.
  */
    async createSpace(options) {
        return this.V1.Space.createSpace(options);
    }
    /**
  * Updates the name, description, or homepage of a space.
  
  -   For security reasons, permissions cannot be updated via the API and
  must be changed via the user interface instead.
  -   Currently you cannot set space labels when updating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: V1.Space.updateSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-put
  * @param options Request options.
  */
    async updateSpace(options) {
        return this.V1.Space.updateSpace(options);
    }
    /**
  * Permanently deletes a space without sending it to the trash. Note, the space will be deleted in a long running task.
  Therefore, the space may not be deleted yet when this method has
  returned. Clients should poll the status link that is returned in the
  response until the task completes.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: V1.Space.deleteSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-delete
  * @param options Request options.
  */
    async deleteSpace(options) {
        return this.V1.Space.deleteSpace(options);
    }
    /**
  * Creates a new space that is only visible to the creator. This method is
  the same as the [Create space](#api-space-post) method with permissions
  set to the current user only. Note, currently you cannot set space
  labels when creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Alternative usage: V1.Space.Private.createSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-private-post
  * @param options Request options.
  */
    async createPrivateSpace(options) {
        return this.V1.Space.Private.createSpace(options);
    }
    /**
  * Returns the settings of a space. Currently only the
  `routeOverrideEnabled` setting can be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space.
  * Alternative usage: V1.Space.Setting.getSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-get
  * @param options Request options.
  */
    async getSpaceSettings(options) {
        return this.V1.Space.Setting.getSettings(options);
    }
    /**
  * Updates the settings for a space. Currently only the
  `routeOverrideEnabled` setting can be updated.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: V1.Space.Setting.updateSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-put
  * @param options Request options.
  */
    async updateSpaceSettings(options) {
        return this.V1.Space.Setting.updateSettings(options);
    }
    /**
  * Updates a content template. Note, blueprint templates cannot be updated
  via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to update a space template or 'Confluence Administrator'
  global permission to update a global template.
  * Alternative usage: V1.Template.updateContentTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-put
  * @param options Request options.
  */
    async updateContentTemplate(options) {
        return this.V1.Template.updateContentTemplate(options);
    }
    /**
  * Creates a new content template. Note, blueprint templates cannot be created via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to create a space template or 'Confluence Administrator'
  global permission to create a global template.
  * Alternative usage: V1.Template.createContentTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-post
  * @param options Request options.
  */
    async createContentTemplate(options) {
        return this.V1.Template.createContentTemplate(options);
    }
    /**
  * Returns all templates provided by blueprints. Use this method to retrieve
  all global blueprint templates or all blueprint templates in a space.
  
  Note, all global blueprints are inherited by each space. Space blueprints
  can be customised without affecting the global blueprints.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view blueprints for the space and permission
  to access the Confluence site ('Can use' global permission) to view global blueprints.
  * Alternative usage: V1.Template.getBlueprintTemplates
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-blueprint-get
  * @param options Request options.
  */
    async getBlueprintTemplates(options) {
        return this.V1.Template.getBlueprintTemplates(options);
    }
    /**
  * Returns all content templates. Use this method to retrieve all global
  content templates or all content templates in a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Alternative usage: V1.Template.getContentTemplates
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-page-get
  * @param options Request options.
  */
    async getContentTemplates(options) {
        return this.V1.Template.getContentTemplates(options);
    }
    /**
  * Returns a content template. This includes information about template,
  like the name, the space or blueprint that the template is in, the body
  of the template, and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Alternative usage: V1.Template.getContentTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-get
  * @param options Request options.
  */
    async getContentTemplate(options) {
        return this.V1.Template.getContentTemplate(options);
    }
    /**
  * Deletes a template. This results in different actions depending on the
  type of template:
  
  - If the template is a content template, it is deleted.
  - If the template is a modified space-level blueprint template, it reverts
  to the template inherited from the global-level blueprint template.
  - If the template is a modified global-level blueprint template, it reverts
  to the default global-level blueprint template.
  
   Note, unmodified blueprint templates cannot be deleted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
          'Admin' permission for the space to delete a space template or 'Confluence Administrator'
          global permission to delete a global template.
  * Alternative usage: V1.Template.removeTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-delete
  * @param options Request options.
  */
    async removeTemplate(options) {
        return this.V1.Template.removeTemplate(options);
    }
    /**
  * Returns all themes, not including the default theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Alternative usage: V1.Theme.getThemes
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-get
  * @param options Request options.
  */
    async getThemes(options) {
        return this.V1.Theme.getThemes(options);
    }
    /**
  * Returns the globally assigned theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Alternative usage: V1.Theme.getGlobalTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-selected-get
  * @param options Request options.
  */
    async getGlobalTheme(options) {
        return this.V1.Theme.getGlobalTheme(options);
    }
    /**
  * Returns a theme. This includes information about the theme name,
  description, and icon.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Alternative usage: V1.Theme.getTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-themekey-get
  * @param options Request options.
  */
    async getTheme(options) {
        return this.V1.Theme.getTheme(options);
    }
    /**
  * Returns the theme selected for a space, if one is set. If no space
  theme is set, this means that the space is inheriting the global look
  and feel settings.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Alternative usage: V1.Theme.getSpaceTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-get
  * @param options Request options.
  */
    async getSpaceTheme(options) {
        return this.V1.Theme.getSpaceTheme(options);
    }
    /**
  * Sets the theme for a space. Note, if you want to reset the space theme to
  the default Confluence theme, use the 'Reset space theme' method instead
  of this method.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: V1.Theme.setSpaceTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-put
  * @param options Request options.
  */
    async setSpaceTheme(options) {
        return this.V1.Theme.setSpaceTheme(options);
    }
    /**
  * Resets the space theme. This means that the space will inherit the
  global look and feel settings
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: V1.Theme.resetSpaceTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-delete
  * @param options Request options.
  */
    async resetSpaceTheme(options) {
        return this.V1.Theme.resetSpaceTheme(options);
    }
    /**
  * Returns a user. This includes information about the user, such as the
  display name, account ID, profile picture, and more. The information returned may be
  restricted by the user's profile visibility settings.
  
  **Note:** to add, edit, or delete users in your organization, see the
  [user management REST API](/cloud/admin/user-management/about/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.User.getUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-group-users
  * @param options Request options.
  */
    async getUser(options) {
        return this.V1.User.getUser(options);
    }
    /**
  * Returns information about how anonymous users are represented, like the
  profile picture and display name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.User.getAnonymousUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-anonymous-get
  * @param options Request options.
  */
    async getAnonymousUser(options) {
        return this.V1.User.getAnonymousUser(options);
    }
    /**
  * Returns the currently logged-in user. This includes information about
  the user, like the display name, userKey, account ID, profile picture,
  and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.User.getCurrentUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-current-get
  * @param options Request options.
  */
    async getCurrentUser(options) {
        return this.V1.User.getCurrentUser(options);
    }
    /**
  * Returns the groups that a user is a member of.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.User.getGroupsWhereUserMember
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-memberof-get
  * @param options Request options.
  */
    async getGroupsWhereUserMember(options) {
        return this.V1.User.getGroupsWhereUserMember(options);
    }
    /**
  * Returns user details for the ids provided in the request.
  Currently this API returns a maximum of 100 results.
  If more than 100 account ids are passed in, then the first 100 will be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.User.getUsersWithIds
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-bulk-get
  * @param options Request options.
  */
    async getUsersWithIds(options) {
        return this.V1.User.getUsersWithIds(options);
    }
    /**
  * Returns a user's email address regardless of the user's profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.User.getUserEmail
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-get
  * @param options Request options.
  */
    async getUserEmail(options) {
        return this.V1.User.getUserEmail(options);
    }
    /**
  * Returns a user's email address regardless of the user’s profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  Any accounts which are not available will not be included in the result.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: V1.User.getUserEmails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-bulk-get
  * @param options Request options.
  */
    async getUserEmails(options) {
        return this.V1.User.getUserEmails(options);
    }
}
class AttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.BlogPost = new AttachmentBlogPostGroup(implementation, this.getGlobalErrorStrategy);
        this.CustomContent = new AttachmentCustomContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new AttachmentLabelGroup(implementation, this.getGlobalErrorStrategy);
        this.Page = new AttachmentPageGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all attachments. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the container of the attachment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-attachments-get
  * @param options Request options.
  */
    async getAttachments(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/attachments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment's container.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-attachments-id-get
  * @param options Request options.
  */
    async getAttachmentById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/attachments/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete an attachment by id.
  
  Deleting an attachment moves the attachment to the trash, where it can be restored later. To permanently delete an attachment (or "purge" it),
  the endpoint must be called on a **trashed** attachment with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the container of the attachment.
  Permission to delete attachments in the space.
  Permission to administer the space (if attempting to purge).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-attachments-id-delete
  * @param options Request options.
  */
    async deleteAttachment(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/api/v2/attachments/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class AttachmentBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the attachments of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-blogposts-id-attachments-get
  * @param options Request options.
  */
    async getAttachments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}/attachments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AttachmentCustomContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the attachments of specific custom content. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the custom content and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-custom-content-id-attachments-get
  * @param options Request options.
  */
    async getAttachments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(id)}/attachments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AttachmentLabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the attachments of specified label. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-labels-id-attachments-get
  * @param options Request options.
  */
    async getAttachments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/labels/${encodeURIComponent(id)}/attachments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AttachmentPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the attachments of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-attachment/#api-pages-id-attachments-get
  * @param options Request options.
  */
    async getAttachments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/attachments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AncestorGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all ancestors for a given page by ID in top-to-bottom order (that is, the highest ancestor is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-pages-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfPage(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/ancestors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all ancestors for a given whiteboard by ID in top-to-bottom order (that is, the highest ancestor is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the whiteboard and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-whiteboards-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfWhiteboard(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/whiteboards/${encodeURIComponent(id)}/ancestors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all ancestors for a given database by ID in top-to-bottom order (that is, the highest ancestor is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the database and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-databases-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfDatabase(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/databases/${encodeURIComponent(id)}/ancestors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all ancestors for a given Smart Link in the content tree by ID in top-to-bottom order (that is, the highest ancestor is
  the first item in the response payload). The number of results is limited by the `limit` parameter and additional results
  (if available) will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get Smart Link in the content tree by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the Smart Link in the content tree and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-embeds-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfSmartLink(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/embeds/${encodeURIComponent(id)}/ancestors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all ancestors for a given folder by ID in top-to-bottom order (that is, the highest ancestor is
  the first item in the response payload). The number of results is limited by the `limit` parameter and additional results
  (if available) will be available by calling this endpoint with the ID of first ancestor in the response payload.
  
  This endpoint returns minimal information about each ancestor. To fetch more details, use a related endpoint, such
  as [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-folders-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the folder and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-ancestors/#api-folders-id-ancestors-get
  * @param options Request options.
  */
    async getAllAncestorsOfFolder(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/folders/${encodeURIComponent(id)}/ancestors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class BlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all blog posts. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only blog posts that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-get
  * @param options Request options.
  */
    async getBlogPosts(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new blog post in the space specified by the spaceId.
  
  By default this will create the blog post as a non-draft, unless the status is specified as draft.
  If creating a non-draft, the title must not be empty.
  
  Currently only supports the storage representation specified in the body.representation enums below
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-post
  * @param options Request options.
  */
    async createBlogPost(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/api/v2/blogposts`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-id-get
  * @param options Request options.
  */
    async getBlogPostById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a blog post by id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space. Permission to update blog posts in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-id-put
  * @param options Request options.
  */
    async updateBlogPost(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/wiki/api/v2/blogposts/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a blog post by id.
  
  By default this will delete blog posts that are non-drafts. To delete a blog post that is a draft, the endpoint must be called on a
  draft with the following param `draft=true`. Discarded drafts are not sent to the trash and are permanently deleted.
  
  Deleting a blog post that is not a draft moves the blog post to the trash, where it can be restored later.
  To permanently delete a blog post (or "purge" it), the endpoint must be called on a **trashed** blog post with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space.
  Permission to delete blog posts in the space.
  Permission to administer the space (if attempting to purge).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-blogposts-id-delete
  * @param options Request options.
  */
    async deleteBlogPost(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the blogposts of specified label. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-labels-id-blogposts-get
  * @param options Request options.
  */
    async getBlogPostsForLabel(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/labels/${encodeURIComponent(id)}/blogposts`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all blog posts in a space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and view the space.
  Only blog posts that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-blog-post/#api-spaces-id-blogposts-get
  * @param options Request options.
  */
    async getBlogPostsInSpace(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces/${encodeURIComponent(id)}/blogposts`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ChildrenGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all children for given whiteboard id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-whiteboards-id-direct-children-get
  * @param options Request options.
  */
    async getWhiteboardDirectChildren(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/whiteboards/${encodeURIComponent(id)}/direct-children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all children for given database id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-databases-id-direct-children-get
  * @param options Request options.
  */
    async getDatabaseDirectChildren(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/databases/${encodeURIComponent(id)}/direct-children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all children for given smart link id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-embeds-id-direct-children-get
  * @param options Request options.
  */
    async getSmartLinkDirectChildren(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/embeds/${encodeURIComponent(id)}/direct-children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all children for given folder id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-folders-id-direct-children-get
  * @param options Request options.
  */
    async getFolderDirectChildren(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/folders/${encodeURIComponent(id)}/direct-children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all child pages for given page id. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only pages that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-pages-id-children-get
  * @param options Request options.
  * @deprecated
  */
    async getChildPages(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all children for given page id in the content tree. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each child. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-pages-id-direct-children-get
  * @param options Request options.
  */
    async getPageDirectChildren(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/direct-children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all child custom content for given custom content id. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only custom content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-children/#api-custom-content-id-children-get
  * @param options Request options.
  */
    async getChildCustomContent(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(id)}/children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attachment = new CommentAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.CustomContent = new CommentCustomContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Footer = new CommentFooterGroup(implementation, this.getGlobalErrorStrategy);
        this.Inline = new CommentInlineGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class CommentAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the comments of the specific attachment.
  The number of results is limited by the `limit` parameter and additional results (if available) will be available through
  the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment and its corresponding containers.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-attachments-id-footer-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/attachments/${encodeURIComponent(id)}/footer-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentCustomContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the comments of the specific custom content.
  The number of results is limited by the `limit` parameter and additional results (if available) will be available through
  the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and its corresponding containers.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-custom-content-id-footer-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(id)}/footer-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentFooterGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Page = new CommentFooterPageGroup(implementation, this.getGlobalErrorStrategy);
        this.BlogPost = new CommentFooterBlogPostGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all footer comments. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the container and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/footer-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Create a footer comment.
  
  The footer comment can be made against several locations:
  - at the top level (specifying pageId or blogPostId in the request body)
  - as a reply (specifying parentCommentId in the request body)
  - against an attachment (note: this is different than the comments added via the attachment properties page on the UI, which are referred to as version comments)
  - against a custom content
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-post
  * @param options Request options.
  */
    async createComment(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/api/v2/footer-comments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a footer comment by id
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the container and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-comment-id-get
  * @param options Request options.
  */
    async getCommentById(options) {
        const { headers, errorStrategy, commentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/footer-comments/${encodeURIComponent(commentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a footer comment. This can be used to update the body text of a comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-comment-id-put
  * @param options Request options.
  */
    async updateComment(options) {
        const { body, headers, errorStrategy, commentId } = options;
        const request = new Request("PUT", `/wiki/api/v2/footer-comments/${encodeURIComponent(commentId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a footer comment. This is a permanent deletion and cannot be reverted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to delete comments in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-comment-id-delete
  * @param options Request options.
  */
    async deleteComment(options) {
        const { headers, errorStrategy, commentId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/footer-comments/${encodeURIComponent(commentId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the children footer comments of specific comment. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-footer-comments-id-children-get
  * @param options Request options.
  */
    async getChildrenComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/footer-comments/${encodeURIComponent(id)}/children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentFooterPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the root footer comments of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-pages-id-footer-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/footer-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentFooterBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the root footer comments of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-blogposts-id-footer-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}/footer-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentInlineGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Page = new CommentInlinePageGroup(implementation, this.getGlobalErrorStrategy);
        this.BlogPost = new CommentInlineBlogPostGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all inline comments. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/inline-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Create an inline comment. This can be at the top level (specifying pageId or blogPostId in the request body)
  or as a reply (specifying parentCommentId in the request body). Note the inlineCommentProperties object in the
  request body is used to select the text the inline comment should be tied to. This is what determines the text
  highlighting when viewing a page in Confluence.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-post
  * @param options Request options.
  */
    async createComment(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/api/v2/inline-comments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves an inline comment by id
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-comment-id-get
  * @param options Request options.
  */
    async getCommentById(options) {
        const { headers, errorStrategy, commentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/inline-comments/${encodeURIComponent(commentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update an inline comment. This can be used to update the body text of a comment and/or to resolve the comment
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create comments in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-comment-id-put
  * @param options Request options.
  */
    async updateComment(options) {
        const { body, headers, errorStrategy, commentId } = options;
        const request = new Request("PUT", `/wiki/api/v2/inline-comments/${encodeURIComponent(commentId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes an inline comment. This is a permanent deletion and cannot be reverted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to delete comments in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-comment-id-delete
  * @param options Request options.
  */
    async deleteComment(options) {
        const { headers, errorStrategy, commentId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/inline-comments/${encodeURIComponent(commentId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the children inline comments of specific comment. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-inline-comments-id-children-get
  * @param options Request options.
  */
    async getChildrenComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/inline-comments/${encodeURIComponent(id)}/children`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentInlinePageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the root inline comments of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-pages-id-inline-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/inline-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommentInlineBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the root inline comments of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-comment/#api-blogposts-id-inline-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}/inline-comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new ContentPropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Converts a list of content ids into their associated content types. This is useful for users migrating from v1 to v2
  who may have stored just content ids without their associated type. This will return types as they should be used in v2.
  Notably, this will return `inline-comment` for inline comments and `footer-comment` for footer comments, which is distinct from them
  both being represented by `comment` in v1.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the requested content. Any content that the user does not have permission to view or does not exist will map to `null` in the response.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content/#api-group-content
  * @param options Request options.
  */
    async convertIdsToTypes(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/api/v2/content/convert-ids-to-types`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attachment = new ContentPropertyAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.BlogPost = new ContentPropertyBlogPostGroup(implementation, this.getGlobalErrorStrategy);
        this.CustomContent = new ContentPropertyCustomContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Page = new ContentPropertyPageGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new ContentPropertyCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Folder = new ContentPropertyFolderGroup(implementation, this.getGlobalErrorStrategy);
        this.Whiteboard = new ContentPropertyWhiteboardGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class ContentPropertyAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves all Content Properties tied to a specified attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-get
  * @param options Request options.
  */
    async getContentProperties(options) {
        const { headers, errorStrategy, attachmentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/attachments/${encodeURIComponent(attachmentId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content property for an attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the attachment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-post
  * @param options Request options.
  */
    async createContentProperty(options) {
        const { body, headers, errorStrategy, attachmentId } = options;
        const request = new Request("POST", `/wiki/api/v2/attachments/${encodeURIComponent(attachmentId)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyById(options) {
        const { headers, errorStrategy, attachmentId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/attachments/${encodeURIComponent(attachmentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a content property for attachment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the attachment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        const { body, headers, errorStrategy, attachmentId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/attachments/${encodeURIComponent(attachmentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property for an attachment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to attachment the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-attachments-attachment-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyById(options) {
        const { headers, errorStrategy, attachmentId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/attachments/${encodeURIComponent(attachmentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentPropertyBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves all Content Properties tied to a specified blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-get
  * @param options Request options.
  */
    async getContentProperties(options) {
        const { headers, errorStrategy, blogPostId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(blogPostId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new property for a blogpost.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the blog post.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-post
  * @param options Request options.
  */
    async createContentProperty(options) {
        const { body, headers, errorStrategy, blogPostId } = options;
        const request = new Request("POST", `/wiki/api/v2/blogposts/${encodeURIComponent(blogPostId)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyById(options) {
        const { headers, errorStrategy, blogPostId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/blogposts/${encodeURIComponent(blogPostId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a content property for blog post by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the blog post.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        const { body, headers, errorStrategy, blogPostId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/blogposts/${encodeURIComponent(blogPostId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property for a blogpost by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the blog post.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-blogposts-blogpost-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyById(options) {
        const { headers, errorStrategy, blogPostId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/blogposts/${encodeURIComponent(blogPostId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentPropertyCustomContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves Content Properties tied to a specified custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-get
  * @param options Request options.
  */
    async getContentProperties(options) {
        const { headers, errorStrategy, customContentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(customContentId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content property for a piece of custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the custom content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-post
  * @param options Request options.
  */
    async createContentProperty(options) {
        const { body, headers, errorStrategy, customContentId } = options;
        const request = new Request("POST", `/wiki/api/v2/custom-content/${encodeURIComponent(customContentId)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyById(options) {
        const { headers, errorStrategy, customContentId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/custom-content/${encodeURIComponent(customContentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a content property for a piece of custom content by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the custom content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        const { body, headers, errorStrategy, customContentId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/custom-content/${encodeURIComponent(customContentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property for a piece of custom content by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the custom content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-custom-content-custom-content-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyById(options) {
        const { headers, errorStrategy, customContentId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/custom-content/${encodeURIComponent(customContentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentPropertyPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves Content Properties tied to a specified page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-get
  * @param options Request options.
  */
    async getContentProperties(options) {
        const { headers, errorStrategy, pageId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(pageId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content property for a page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-post
  * @param options Request options.
  */
    async createContentProperty(options) {
        const { body, headers, errorStrategy, pageId } = options;
        const request = new Request("POST", `/wiki/api/v2/pages/${encodeURIComponent(pageId)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyById(options) {
        const { headers, errorStrategy, pageId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/pages/${encodeURIComponent(pageId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a content property for a page by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        const { body, headers, errorStrategy, pageId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/pages/${encodeURIComponent(pageId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property for a page by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-pages-page-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyById(options) {
        const { headers, errorStrategy, pageId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/pages/${encodeURIComponent(pageId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentPropertyCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves Content Properties attached to a specified comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the comment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-get
  * @param options Request options.
  */
    async getContentProperties(options) {
        const { headers, errorStrategy, commentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/comments/${encodeURIComponent(commentId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content property for a comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the comment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-post
  * @param options Request options.
  */
    async createContentProperty(options) {
        const { body, headers, errorStrategy, commentId } = options;
        const request = new Request("POST", `/wiki/api/v2/comments/${encodeURIComponent(commentId)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the comment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyById(options) {
        const { headers, errorStrategy, commentId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/comments/${encodeURIComponent(commentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a content property for a comment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the comment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        const { body, headers, errorStrategy, commentId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/comments/${encodeURIComponent(commentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property for a comment by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the comment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-comments-comment-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyById(options) {
        const { headers, errorStrategy, commentId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/comments/${encodeURIComponent(commentId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentPropertyFolderGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves Content Properties tied to a specified folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-id-properties-get
  * @param options Request options.
  */
    async getContentProperties(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/folders/${encodeURIComponent(id)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content property for a folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the folder.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-id-properties-post
  * @param options Request options.
  */
    async createContentProperty(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/wiki/api/v2/folders/${encodeURIComponent(id)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-folder-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyById(options) {
        const { headers, errorStrategy, folderId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/folders/${encodeURIComponent(folderId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a content property for a folder by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the folder.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-folder-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        const { body, headers, errorStrategy, folderId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/folders/${encodeURIComponent(folderId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property for a folder by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the folder.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-folders-folder-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyById(options) {
        const { headers, errorStrategy, folderId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/folders/${encodeURIComponent(folderId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentPropertyWhiteboardGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves Content Properties tied to a specified whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-id-properties-get
  * @param options Request options.
  */
    async getContentProperties(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/whiteboards/${encodeURIComponent(id)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content property for a whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the whiteboard.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-id-properties-post
  * @param options Request options.
  */
    async createContentProperty(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/wiki/api/v2/whiteboards/${encodeURIComponent(id)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves a specific Content Property by ID that is attached to a specified whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-whiteboard-id-properties-property-id-get
  * @param options Request options.
  */
    async getContentPropertyById(options) {
        const { headers, errorStrategy, whiteboardId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/whiteboards/${encodeURIComponent(whiteboardId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a content property for a whiteboard by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the whiteboard.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-whiteboard-id-properties-property-id-put
  * @param options Request options.
  */
    async updateContentPropertyById(options) {
        const { body, headers, errorStrategy, whiteboardId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/whiteboards/${encodeURIComponent(whiteboardId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property for a whiteboard by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the whiteboard.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-content-properties/#api-whiteboards-whiteboard-id-properties-property-id-delete
  * @param options Request options.
  */
    async deleteContentPropertyById(options) {
        const { headers, errorStrategy, whiteboardId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/whiteboards/${encodeURIComponent(whiteboardId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class CustomContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.BlogPost = new CustomContentBlogPostGroup(implementation, this.getGlobalErrorStrategy);
        this.Page = new CustomContentPageGroup(implementation, this.getGlobalErrorStrategy);
        this.Space = new CustomContentSpaceGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all custom content for a given type. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content, and the corresponding space (if different from the container).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-blogposts-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByType(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new custom content in the given space, page, blogpost or other custom content.
  
  Only one of `spaceId`, `pageId`, `blogPostId`, or `customContentId` is required in the request body.
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to create custom content in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-post
  * @param options Request options.
  */
    async createCustomContent(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/api/v2/custom-content`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific piece of custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content, and the corresponding space (if different from the container).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-id-get
  * @param options Request options.
  */
    async getCustomContentById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a custom content by id.
  At most one of `spaceId`, `pageId`, `blogPostId`, or `customContentId` is allowed in the request body.
  Note that if `spaceId` is specified, it must be the same as the `spaceId` used for creating the custom content
  as moving custom content to a different space is not supported.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space. Permission to update custom content in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-id-put
  * @param options Request options.
  */
    async updateCustomContent(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/wiki/api/v2/custom-content/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a custom content by id.
  
  Deleting a custom content will either move it to the trash or permanently delete it (purge it), depending on the apiSupport.
  To permanently delete a **trashed** custom content, the endpoint must be called with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blogpost and its corresponding space.
  Permission to delete custom content in the space.
  Permission to administer the space (if attempting to purge).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-custom-content-id-delete
  * @param options Request options.
  */
    async deleteCustomContent(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class CustomContentBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all custom content for a given type within a given blogpost. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content (blog post), and the corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-blogposts-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByType(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}/custom-content`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CustomContentPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all custom content for a given type within a given page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content, the container of the custom content (page), and the corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-pages-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByType(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/custom-content`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CustomContentSpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all custom content for a given type within a given space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and the corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-custom-content/#api-spaces-id-custom-content-get
  * @param options Request options.
  */
    async getCustomContentByType(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces/${encodeURIComponent(id)}/custom-content`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attachment = new LabelAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.BlogPost = new LabelBlogPostGroup(implementation, this.getGlobalErrorStrategy);
        this.CustomContent = new LabelCustomContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Page = new LabelPageGroup(implementation, this.getGlobalErrorStrategy);
        this.Space = new LabelSpaceGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all labels. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only labels that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-labels-get
  * @param options Request options.
  */
    async getLabels(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the labels of specific attachment. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the parent content of the attachment and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-attachments-id-labels-get
  * @param options Request options.
  */
    async getLabels(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/attachments/${encodeURIComponent(id)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the labels of specific blog post. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-blogposts-id-labels-get
  * @param options Request options.
  */
    async getLabels(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelCustomContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the labels for a specific piece of custom content. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-custom-content-id-labels-get
  * @param options Request options.
  */
    async getLabels(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(id)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the labels of specific page. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  Only labels that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-pages-id-labels-get
  * @param options Request options.
  */
    async getLabels(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelSpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the labels of specific space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the space.
  Only labels that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-spaces-id-labels-get
  * @param options Request options.
  */
    async getLabels(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces/${encodeURIComponent(id)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the labels of space content (pages, blogposts etc). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the space.
  Only labels that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-label/#api-spaces-id-content-labels-get
  * @param options Request options.
  */
    async getLabelsForContent(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces/${encodeURIComponent(id)}/content/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LikeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.BlogPost = new LikeBlogPostGroup(implementation, this.getGlobalErrorStrategy);
        this.Page = new LikePageGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new LikeCommentGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class LikeBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the count of likes of specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-blogposts-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCount(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/api/v2/blogposts/${encodeURIComponent(id)}/likes/count`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the account IDs of likes of specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-blogposts-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikes(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}/likes/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LikePageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the count of likes of specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-pages-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCount(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/api/v2/pages/${encodeURIComponent(id)}/likes/count`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the account IDs of likes of specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-pages-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikes(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/likes/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LikeCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Footer = new LikeCommentFooterGroup(implementation, this.getGlobalErrorStrategy);
        this.Inline = new LikeCommentInlineGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class LikeCommentFooterGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the count of likes of specific footer comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-footer-comments-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCount(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/api/v2/footer-comments/${encodeURIComponent(id)}/likes/count`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the account IDs of likes of specific footer comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-footer-comments-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikes(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/footer-comments/${encodeURIComponent(id)}/likes/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LikeCommentInlineGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the count of likes of specific inline comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-inline-comments-id-likes-count-get
  * @param options Request options.
  */
    async getLikeCount(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/api/v2/inline-comments/${encodeURIComponent(id)}/likes/count`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the account IDs of likes of specific inline comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page/blogpost and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-like/#api-inline-comments-id-likes-users-get
  * @param options Request options.
  */
    async getAccountIdsOfLikes(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/inline-comments/${encodeURIComponent(id)}/likes/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the pages of specified label. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-labels-id-pages-get
  * @param options Request options.
  */
    async getPagesForLabel(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/labels/${encodeURIComponent(id)}/pages`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all pages. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only pages that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-get
  * @param options Request options.
  */
    async getPages(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a page in the space.
  
  Pages are created as published by default unless specified as a draft in the status field. If creating a published page, the title must be specified.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a page in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-post
  * @param options Request options.
  */
    async createPage(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/api/v2/pages`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get
  * @param options Request options.
  */
    async getPageById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a page by id.
  
  When the "current" version is updated, the provided body content is considered as the latest version. This latest body content
  will be attempted to be merged into the draft version through a content reconciliation algorithm. If two versions are significantly diverged,
  the latest provided content may entirely override what was previously in the draft.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space. Permission to update pages in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-put
  * @param options Request options.
  */
    async updatePage(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/wiki/api/v2/pages/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a page by id.
  
  By default this will delete pages that are non-drafts. To delete a page that is a draft, the endpoint must be called on a
  draft with the following param `draft=true`. Discarded drafts are not sent to the trash and are permanently deleted.
  
  Deleting a page moves the page to the trash, where it can be restored later. To permanently delete a page (or "purge" it),
  the endpoint must be called on a **trashed** page with the following param `purge=true`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space.
  Permission to delete pages in the space.
  Permission to administer the space (if attempting to purge).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-delete
  * @param options Request options.
  */
    async deletePage(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns all pages in a space. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'View' permission for the space.
  Only pages that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-spaces-id-pages-get
  * @param options Request options.
  */
    async getPagesInSpace(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces/${encodeURIComponent(id)}/pages`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new SpacePropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all spaces. The results will be sorted by id ascending. The number of results is limited by the `limit` parameter and
  additional results (if available) will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only spaces that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space/#api-spaces-get
  * @param options Request options.
  */
    async getSpaces(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space/#api-spaces-id-get
  * @param options Request options.
  */
    async getSpaceById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpacePropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all properties for the given space. Space properties are a key-value storage associated with a space.
  The limit parameter specifies the maximum number of results returned in a single response. Use the `link` response header
  to paginate through additional results.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'View' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-get
  * @param options Request options.
  */
    async getProperties(options) {
        const { headers, errorStrategy, spaceId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/spaces/${encodeURIComponent(spaceId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new space property.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-post
  * @param options Request options.
  */
    async createProperty(options) {
        const { body, headers, errorStrategy, spaceId } = options;
        const request = new Request("POST", `/wiki/api/v2/spaces/${encodeURIComponent(spaceId)}/properties`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieve a space property by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'View' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-property-id-get
  * @param options Request options.
  */
    async getPropertyById(options) {
        const { headers, errorStrategy, spaceId, propertyId } = options;
        const request = new Request("GET", `/wiki/api/v2/spaces/${encodeURIComponent(spaceId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a space property by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-property-id-put
  * @param options Request options.
  */
    async updatePropertyById(options) {
        const { body, headers, errorStrategy, spaceId, propertyId } = options;
        const request = new Request("PUT", `/wiki/api/v2/spaces/${encodeURIComponent(spaceId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a space property by its id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission) and 'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-space-properties/#api-spaces-space-id-properties-property-id-delete
  * @param options Request options.
  */
    async deletePropertyById(options) {
        const { headers, errorStrategy, spaceId, propertyId } = options;
        const request = new Request("DELETE", `/wiki/api/v2/spaces/${encodeURIComponent(spaceId)}/properties/${encodeURIComponent(propertyId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class TaskGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all tasks. The number of results is limited by the `limit` parameter and additional results (if available)
  will be available through the `next` URL present in the `Link` response header.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only tasks that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-task/#api-tasks-get
  * @param options Request options.
  */
    async getTasks(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/api/v2/tasks`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific task.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the containing page or blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-task/#api-tasks-id-get
  * @param options Request options.
  */
    async getTaskById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/tasks/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Update a task by id. This endpoint currently only supports updating task status.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the containing page or blog post and view its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-task/#api-tasks-id-get
  * @param options Request options.
  */
    async updateTask(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/api/v2/tasks/${encodeURIComponent(id)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class VersionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attachment = new VersionAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.BlogPost = new VersionBlogPostGroup(implementation, this.getGlobalErrorStrategy);
        this.Page = new VersionPageGroup(implementation, this.getGlobalErrorStrategy);
        this.CustomContent = new VersionCustomContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new VersionCommentGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class VersionAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the versions of specific attachment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-attachments-id-versions-get
  * @param options Request options.
  */
    async getVersions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/attachments/${encodeURIComponent(id)}/versions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves version details for the specified attachment and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the attachment.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-attachments-attachment-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetails(options) {
        const { headers, errorStrategy, attachmentId, versionNumber } = options;
        const request = new Request("GET", `/wiki/api/v2/attachments/${encodeURIComponent(attachmentId)}/versions/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class VersionBlogPostGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the versions of specific blog post.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-blogposts-id-versions-get
  * @param options Request options.
  */
    async getVersions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/blogposts/${encodeURIComponent(id)}/versions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves version details for the specified blog post and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the blog post.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-blogposts-blogpost-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetails(options) {
        const { headers, errorStrategy, blogPostId, versionNumber } = options;
        const request = new Request("GET", `/wiki/api/v2/blogposts/${encodeURIComponent(blogPostId)}/versions/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class VersionPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the versions of specific page.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-pages-id-versions-get
  * @param options Request options.
  */
    async getVersions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/versions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves version details for the specified page and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-pages-page-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetails(options) {
        const { headers, errorStrategy, pageId, versionNumber } = options;
        const request = new Request("GET", `/wiki/api/v2/pages/${encodeURIComponent(pageId)}/versions/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class VersionCustomContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the versions of specific custom content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the custom content and its corresponding page and space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-custom-content-custom-content-id-versions-get
  * @param options Request options.
  */
    async getVersions(options) {
        const { headers, errorStrategy, customContentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/custom-content/${encodeURIComponent(customContentId)}/versions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves version details for the specified custom content and version number.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-custom-content-custom-content-id-versions-get
  * @param options Request options.
  */
    async getVersionDetails(options) {
        const { headers, errorStrategy, customContentId, versionNumber } = options;
        const request = new Request("GET", `/wiki/api/v2/custom-content/${encodeURIComponent(customContentId)}/versions/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class VersionCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Footer = new VersionCommentFooterGroup(implementation, this.getGlobalErrorStrategy);
        this.Inline = new VersionCommentInlineGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class VersionCommentFooterGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves the versions of the specified footer comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-footer-comments-id-versions-get
  * @param options Request options.
  */
    async getVersions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/footer-comments/${encodeURIComponent(id)}/versions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves version details for the specified footer comment version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-footer-comments-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetails(options) {
        const { headers, errorStrategy, id, versionNumber } = options;
        const request = new Request("GET", `/wiki/api/v2/footer-comments/${encodeURIComponent(id)}/versions/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class VersionCommentInlineGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Retrieves the versions of the specified inline comment.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-inline-comments-id-versions-get
  * @param options Request options.
  */
    async getVersions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/inline-comments/${encodeURIComponent(id)}/versions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Retrieves version details for the specified inline comment version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content of the page or blog post and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-version/#api-inline-comments-id-versions-version-number-get
  * @param options Request options.
  */
    async getVersionDetails(options) {
        const { headers, errorStrategy, id, versionNumber } = options;
        const request = new Request("GET", `/wiki/api/v2/inline-comments/${encodeURIComponent(id)}/versions/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WhiteboardGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a whiteboard in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a whiteboard in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-post
  * @param options Request options.
  */
    async createWhiteboard(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/api/v2/whiteboards`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific whiteboard.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get
  * @param options Request options.
  */
    async getWhiteboardById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/whiteboards/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a whiteboard by id.
  
  Deleting a whiteboard moves the whiteboard to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the whiteboard and its corresponding space.
  Permission to delete whiteboards in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-delete
  * @param options Request options.
  */
    async deleteWhiteboard(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/wiki/api/v2/whiteboards/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class DescendantGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns descendants in the content tree for a given whiteboard by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the whiteboard and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-whiteboards-id-descendants-get
  * @param options Request options.
  */
    async getWhiteboardDescendants(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/whiteboards/${encodeURIComponent(id)}/descendants`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns descendants in the content tree for a given database by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the database and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-databases-id-descendants-get
  * @param options Request options.
  */
    async getDatabaseDescendants(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/databases/${encodeURIComponent(id)}/descendants`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns descendants in the content tree for a given smart link by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the smart link and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-embeds-id-descendants-get
  * @param options Request options.
  */
    async getSmartLinkDescendants(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/embeds/${encodeURIComponent(id)}/descendants`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns descendants in the content tree for a given folder by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the  and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-folders-id-descendants-get
  * @param options Request options.
  */
    async getFolderDescendants(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/folders/${encodeURIComponent(id)}/descendants`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns descendants in the content tree for a given page by ID in top-to-bottom order (that is, the highest descendant is the first
  item in the response payload). The number of results is limited by the `limit` parameter and additional results (if available)
  will be available by calling this endpoint with the cursor in the response payload. There is also a `depth` parameter specifying depth
  of descendants to be fetched.
  
  The following types of content will be returned:
  - Database
  - Embed
  - Folder
  - Page
  - Whiteboard
  
  This endpoint returns minimal information about each descendant. To fetch more details, use a related endpoint based on the content type, such
  as:
  
  - [Get database by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get)
  - [Get embed by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get)
  - [Get folder by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get)
  - [Get page by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-page/#api-pages-id-get)
  - [Get whiteboard by id](https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-whiteboard/#api-whiteboards-id-get).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Permission to view the page and its corresponding space
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-descendants/#api-pages-id-descendants-get
  * @param options Request options.
  */
    async getPageDescendants(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/pages/${encodeURIComponent(id)}/descendants`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FolderGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a folder in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a folder in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-post
  * @param options Request options.
  */
    async createFolder(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/api/v2/folders`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific folder.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-get
  * @param options Request options.
  */
    async getFolderById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/folders/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a folder by id.
  
  Deleting a folder moves the folder to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the folder and its corresponding space.
  Permission to delete folders in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-folder/#api-folders-id-delete
  * @param options Request options.
  */
    async deleteFolder(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/wiki/api/v2/folders/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class DatabaseGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a database in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a database in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-post
  * @param options Request options.
  */
    async createDatabase(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/api/v2/databases`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific database.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the database and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-get
  * @param options Request options.
  */
    async getDatabaseById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/databases/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a database by id.
  
  Deleting a database moves the database to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the database and its corresponding space.
  Permission to delete databases in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-database/#api-databases-id-delete
  * @param options Request options.
  */
    async deleteDatabase(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/wiki/api/v2/databases/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class SmartLinkGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a Smart Link in the content tree in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the corresponding space. Permission to create a Smart Link in the content tree in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-post
  * @param options Request options.
  */
    async createSmartLink(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/api/v2/embeds`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a specific Smart Link in the content tree.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the Smart Link in the content tree and its corresponding space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-get
  * @param options Request options.
  */
    async getSmartLinkById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/api/v2/embeds/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a Smart Link in the content tree by id.
  
  Deleting a Smart Link in the content tree moves the Smart Link to the trash, where it can be restored later
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the Smart Link in the content tree and its corresponding space.
  Permission to delete Smart Links in the content tree in the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v2/api-group-smart-link/#api-embeds-id-delete
  * @param options Request options.
  */
    async deleteSmartLink(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/wiki/api/v2/embeds/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1Group {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Content = new V1ContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Watcher = new V1WatcherGroup(implementation, this.getGlobalErrorStrategy);
        this.UserGroup = new V1UserGroupGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new V1LabelGroup(implementation, this.getGlobalErrorStrategy);
        this.LongRunningTask = new V1LongRunningTaskGroup(implementation, this.getGlobalErrorStrategy);
        this.Relation = new V1RelationGroup(implementation, this.getGlobalErrorStrategy);
        this.Search = new V1SearchGroup(implementation, this.getGlobalErrorStrategy);
        this.Setting = new V1SettingGroup(implementation, this.getGlobalErrorStrategy);
        this.Space = new V1SpaceGroup(implementation, this.getGlobalErrorStrategy);
        this.Template = new V1TemplateGroup(implementation, this.getGlobalErrorStrategy);
        this.Theme = new V1ThemeGroup(implementation, this.getGlobalErrorStrategy);
        this.User = new V1UserGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class V1ContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attachment = new V1ContentAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Body = new V1ContentBodyGroup(implementation, this.getGlobalErrorStrategy);
        this.Move = new V1ContentMoveGroup(implementation, this.getGlobalErrorStrategy);
        this.Descendant = new V1ContentDescendantGroup(implementation, this.getGlobalErrorStrategy);
        this.Copy = new V1ContentCopyGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new V1ContentLabelGroup(implementation, this.getGlobalErrorStrategy);
        this.Restriction = new V1ContentRestrictionGroup(implementation, this.getGlobalErrorStrategy);
        this.Version = new V1ContentVersionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Publishes a shared draft of a page created from a blueprint.
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-put
  * @param options Request options.
  */
    async publishSharedDraft(options) {
        const { body, headers, errorStrategy, draftId, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/blueprint/instance/${encodeURIComponent(draftId)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Publishes a legacy draft of a page created from a blueprint. Legacy drafts
  will eventually be removed in favor of shared drafts. For now, this method
  works the same as [Publish shared draft](#api-content-blueprint-instance-draftId-put).
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-post
  * @param options Request options.
  */
    async publishLegacyDraft(options) {
        const { body, headers, errorStrategy, draftId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/blueprint/instance/${encodeURIComponent(draftId)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the list of content that matches a Confluence Query Language
  (CQL) query. For information on CQL, see:
  [Advanced searching using CQL](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Example initial call:
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-search-get
  * @param options Request options.
  */
    async searchContentByCql(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Adds an attachment to a piece of content. If the attachment already exists
  for the content, then the attachment is updated (i.e. a new version of the
  attachment is created).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a piece of
  content (id='123') with a comment and `minorEdits`=true. If the 'example.txt'
  file already exists, it will update it with a new version of the attachment.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X PUT \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-put
  * @param options Request options.
  */
    async createOrUpdateAttachment(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const formBody = new FormData();
        formBody.setBufferImplementation(this.implementation);
        formBody.append("comment", body.comment, "");
        formBody.append("minorEdit", body.minorEdit, "");
        formBody.append("file", new Blob(this.implementation, [body.file], {}), body.fileName);
        const bodyBlob = formBody.getBlob();
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment`, queryParams), constructHeaders(bodyBlob, headers), bodyBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds an attachment to a piece of content. This method only adds a new
  attachment. If you want to update an existing attachment, use
  [Create or update attachments](#api-content-id-child-attachment-put).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a container
  (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-post
  * @param options Request options.
  */
    async createAttachment(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const formBody = new FormData();
        formBody.setBufferImplementation(this.implementation);
        formBody.append("comment", body.comment, "");
        formBody.append("minorEdit", body.minorEdit, "");
        formBody.append("file", new Blob(this.implementation, [body.file], {}), body.fileName);
        const bodyBlob = formBody.getBlob();
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment`, queryParams), constructHeaders(bodyBlob, headers), bodyBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the attachment properties, i.e. the non-binary data of an attachment
  like the filename, media-type, comment, and parent container.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-put
  * @param options Request options.
  */
    async updateAttachmentProperties(options) {
        const { body, headers, errorStrategy, id, attachmentId } = options;
        const request = new Request("PUT", `/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment/${encodeURIComponent(attachmentId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the binary data of an attachment, given the attachment ID, and
  optionally the comment and the minor edit field.
  
  This method is essentially the same as [Create or update attachments](#api-content-id-child-attachment-put),
  except that it matches the attachment ID rather than the name.
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command updates an attachment (id='att456') that is attached
  to a piece of content (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment/att456/data
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-data-post
  * @param options Request options.
  */
    async updateAttachmentData(options) {
        const { body, headers, errorStrategy, id, attachmentId } = options;
        const formBody = new FormData();
        formBody.setBufferImplementation(this.implementation);
        formBody.append("comment", body.comment, "");
        formBody.append("minorEdit", body.minorEdit, "");
        formBody.append("file", new Blob(this.implementation, [body.file], {}), body.fileName);
        const bodyBlob = formBody.getBlob();
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment/${encodeURIComponent(attachmentId)}/data`, constructHeaders(bodyBlob, headers), bodyBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentBodyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Macro = new V1ContentBodyMacroGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Deprecated, use the [single asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post)
  or the [bulk asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-bulk-tasks-post) instead.
  
  Converts a content body from one format to another format.
  
  Supported conversions:
  
  - storage: view, export_view, styled_view, editor
  - editor: storage
  - view: none
  - export_view: none
  - styled_view: none
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-to-post
  * @param options Request options.
  * @deprecated
  */
    async convertBody(options) {
        const { body, headers, errorStrategy, to, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/contentbody/convert/${encodeURIComponent(to)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Converts a content body from one format to another format asynchronously.
  Returns the asyncId for the asynchronous task.
  
  Supported conversions:
  
  - atlas_doc_format: editor, export_view, storage, styled_view, view
  - storage: atlas_doc_format, editor, export_view, styled_view, view
  - editor: storage
  
  No other conversions are supported at the moment.
  Once a conversion is completed, it will be available for 5 minutes at the result endpoint.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post
  * @param options Request options.
  */
    async asyncConvertBody(options) {
        const { body, headers, errorStrategy, to, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/contentbody/convert/async/${encodeURIComponent(to)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the asynchronous content body for the corresponding id if the task is complete
  or returns the status of the task.
  
  After the task is completed, the result can be obtained for 5 minutes, or until an identical conversion request is made again,
  with allowCache query param set to false.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-id-get
  * @param options Request options.
  */
    async getAsyncConvertResult(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/rest/api/contentbody/convert/async/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentBodyMacroGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the body of a macro in storage format, for the given macro ID.
  This includes information like the name of the macro, the body of the macro,
  and any macro parameters. This method is mainly used by Cloud apps.
  
  About the macro ID: When a macro is created in a new version of content,
  Confluence will generate a random ID for it, unless an ID is specified
  (by an app). The macro ID will look similar to this: '50884bd9-0cb8-41d5-98be-f80943c14f96'.
  The ID is then persisted as new versions of content are created, and is
  only modified by Confluence if there are conflicting IDs.
  
  For Forge macros, the value for macro ID is the "local ID" of that particular ADF node.
  This value can be retrieved either client-side by calling view.getContext() and accessing "localId"
  on the resulting object, or server-side by examining the "local-id" parameter node inside the "parameters" node.
  
  Note that there are other attributes named "local-id", but only this particular one is used to store the macro ID.
  
  Example:
  <ac:adf-node type="extension">
    <ac:adf-attribute key="extension-type">com.atlassian.ecosystem</ac:adf-attribute>
    <ac:adf-attribute key="parameters">
        <ac:adf-parameter key="local-id">e9c4aa10-73fa-417c-888d-48c719ae4165</ac:adf-parameter>
    </ac:adf-parameter>
  </ac:adf-node>
  
  Note, to preserve backwards compatibility this resource will also match on
  the hash of the macro body, even if a macro ID is found. This check will
  eventually become redundant, as macro IDs are generated for pages and
  transparently propagate out to all instances.
  
  This backwards compatibility logic does not apply to Forge macros; those
  can only be retrieved by their ID.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content that the macro is in.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---macro-body/#api-wiki-rest-api-content-id-history-version-macro-id-macroid-get
  * @param options Request options.
  */
    async getMacroById(options) {
        const { headers, errorStrategy, id, version, macroId } = options;
        const request = new Request("GET", `/wiki/rest/api/content/${encodeURIComponent(id)}/history/${encodeURIComponent(version)}/macro/id/${encodeURIComponent(macroId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentMoveGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Move a page to a new location relative to a target page:
  
  * `before` - move the page under the same parent as the target, before the target in the list of children
  * `after` - move the page under the same parent as the target, after the target in the list of children
  * `append` - move the page to be a child of the target
  
  Caution: This API can move pages to the top level of a space. Top-level pages are difficult to find in the UI
  because they do not show up in the page tree display. To avoid this, never use `before` or `after` positions
  when the `targetId` is a top-level page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-pageid-move-position-targetid-put
  * @param options Request options.
  */
    async movePageToNewLocationRelativeToTargetPage(options) {
        const { headers, errorStrategy, pageId, position, targetId } = options;
        const request = new Request("PUT", `/wiki/rest/api/content/${encodeURIComponent(pageId)}/move/${encodeURIComponent(position)}/${encodeURIComponent(targetId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentDescendantGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a map of the descendants of a piece of content. This is similar
  to [Get content children](#api-content-id-child-get), except that this
  method returns child pages at all levels, rather than just the direct
  child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  The map will always include all descendant types that are valid for the content.
  However, if the content has no instances of a descendant type, the map will
  contain an empty array for that descendant type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-get
  * @param options Request options.
  * @deprecated
  */
    async getDescendants(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/descendant`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all descendants of a given type, for a piece of content. This is
  similar to [Get content children by type](#api-content-id-child-type-get),
  except that this method returns child pages at all levels, rather than just
  the direct child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  Custom content types that are provided by apps can also be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-type-get
  * @param options Request options.
  * @deprecated
  */
    async getDescendantsByType(options) {
        const { headers, errorStrategy, id, type, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/descendant/${encodeURIComponent(type)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentCopyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Copy page hierarchy allows the copying of an entire hierarchy of pages and their associated properties, permissions and attachments.
   The id path parameter refers to the content id of the page to copy, and the new parent of this copied page is defined using the destinationPageId in the request body.
   The titleOptions object defines the rules of renaming page titles during the copy;
   for example, search and replace can be used in conjunction to rewrite the copied page titles.
  
   Response example:
   <pre><code>
   {
        "id" : "1180606",
        "links" : {
             "status" : "/rest/api/longtask/1180606"
        }
   }
   </code></pre>
   Use the /longtask/<taskId> REST API to get the copy task status.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-pagehierarchy-copy-post
  * @param options Request options.
  */
    async copyPageHierarchy(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/pagehierarchy/copy`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Copies a single page and its associated properties, permissions, attachments, and custom contents.
   The `id` path parameter refers to the content ID of the page to copy. The target of the page to be copied
   is defined using the `destination` in the request body and can be one of the following types.
  
    - `space`: page will be copied to the specified space as a root page on the space
    - `parent_page`: page will be copied as a child of the specified parent page
    - `existing_page`: page will be copied and replace the specified page
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Add' permission for the space that the content will be copied in and permission to update the content if copying to an `existing_page`.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-copy-post
  * @param options Request options.
  */
    async copySinglePage(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/copy`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentLabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Adds labels to a piece of content. Does not modify the existing labels.
  
  Notes:
  
  - Labels can also be added when creating content ([Create content](#api-content-post)).
  - Labels can be updated when updating content ([Update content](#api-content-id-put)).
  This will delete the existing labels and replace them with the labels in
  the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-post
  * @param options Request options.
  */
    async addLabel(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/label`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content](#api-content-id-label-label-delete)
  except that the label name is specified via a query parameter.
  
  Use this method if the label name has "/" characters, as
  [Remove label from content using query parameter](#api-content-id-label-delete)
  does not accept "/" characters for the label name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-delete
  * @param options Request options.
  */
    async removeLabelWithQueryParameter(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/label`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content using query parameter](#api-content-id-label-delete)
  except that the label name is specified via a path parameter.
  
  Use this method if the label name does not have "/" characters, as the path
  parameter does not accept "/" characters for security reasons. Otherwise,
  use [Remove label from content using query parameter](#api-content-id-label-delete).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-label-delete
  * @param options Request options.
  */
    async removeLabel(options) {
        const { headers, errorStrategy, id, label } = options;
        const request = new Request("DELETE", `/wiki/rest/api/content/${encodeURIComponent(id)}/label/${encodeURIComponent(label)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1ContentRestrictionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Group = new V1ContentRestrictionGroupGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns the restrictions on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-get
  * @param options Request options.
  */
    async getRestrictions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates restrictions for a piece of content. This removes the existing
  restrictions and replaces them with the restrictions in the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-put
  * @param options Request options.
  */
    async updateRestrictions(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds restrictions to a piece of content. Note, this does not change any
  existing restrictions on the content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-post
  * @param options Request options.
  */
    async addRestrictions(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes all restrictions (read and update) on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-delete
  * @param options Request options.
  */
    async deleteRestrictions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns restrictions on a piece of content by operation. This method is
  similar to [Get restrictions](#api-content-id-restriction-get) except that
  the operations are properties of the return object, rather than items in
  a results array.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-get
  * @param options Request options.
  */
    async getRestrictionsByOperation(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the restictions on a piece of content for a given operation (read
  or update).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-get
  * @param options Request options.
  */
    async getRestrictionsForOperation(options) {
        const { headers, errorStrategy, id, operationKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1ContentRestrictionGroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether the specified content restriction applies to a group.
  For example, if a page with `id=123` has a `read` restriction for the `123456` group id,
  the following request will return `true`:
  
  `/wiki/rest/api/content/123/restriction/byOperation/read/byGroupId/123456`
  
  Note that a response of `true` does not guarantee that the group can view the page, as it does not account for
  account-inherited restrictions, space permissions, or even product access. For more
  information, see [Confluence permissions](https://confluence.atlassian.com/x/_AozKw).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-get
  * @param options Request options.
  */
    async getGroupStatus(options) {
        const { headers, errorStrategy, id, operationKey, groupId } = options;
        const request = new Request("GET", `/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/byGroupId/${encodeURIComponent(groupId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Adds a group to a content restriction by Group Id. That is, grant read or update
  permission to the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-put
  * @param options Request options.
  */
    async addGroup(options) {
        const { headers, errorStrategy, id, operationKey, groupId } = options;
        const request = new Request("PUT", `/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/byGroupId/${encodeURIComponent(groupId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a group from a content restriction. That is, remove read or update
  permission for the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-delete
  * @param options Request options.
  */
    async removeGroup(options) {
        const { headers, errorStrategy, id, operationKey, groupId } = options;
        const request = new Request("DELETE", `/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/byGroupId/${encodeURIComponent(groupId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1ContentVersionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Restores a historical version to be the latest version. That is, a new version
  is created with the content of the historical version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-post
  * @param options Request options.
  */
    async restoreVersion(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/version`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a historical version. This does not delete the changes made to the
  content in that version, rather the changes for the deleted version are
  rolled up into the next version. Note, you cannot delete the current version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-versionnumber-delete
  * @param options Request options.
  */
    async deleteVersion(options) {
        const { headers, errorStrategy, id, versionNumber } = options;
        const request = new Request("DELETE", `/wiki/rest/api/content/${encodeURIComponent(id)}/version/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1WatcherGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Content = new V1WatcherContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new V1WatcherLabelGroup(implementation, this.getGlobalErrorStrategy);
        this.Space = new V1WatcherSpaceGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns the watches for a page. A user that watches a page will receive
  receive notifications when the page is updated.
  
  If you want to manage watches for a page, use the following `user` methods:
  
  - [Get content watch status for user](#api-user-watch-content-contentId-get)
  - [Add content watch](#api-user-watch-content-contentId-post)
  - [Remove content watch](#api-user-watch-content-contentId-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-child-created-get
  * @param options Request options.
  */
    async getWatchesForPage(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/notification/child-created`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all space watches for the space that the content is in. A user that
  watches a space will receive receive notifications when any content in the
  space is updated.
  
  If you want to manage watches for a space, use the following `user` methods:
  
  - [Get space watch status for user](#api-user-watch-space-spaceKey-get)
  - [Add space watch](#api-user-watch-space-spaceKey-post)
  - [Remove space watch](#api-user-watch-space-spaceKey-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-created-get
  * @param options Request options.
  */
    async getWatchesForSpace(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/notification/created`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a list of watchers of a space
     * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-space-spacekey-watch-get
     * @param options Request options.
     */
    async getSpaceWatchers(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/watch`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1WatcherContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether a user is watching a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-get
  * @param options Request options.
  */
    async getWatcherStatus(options) {
        const { headers, errorStrategy, contentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user as a watcher to a piece of content. Choose the user by doing
  one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-post
  * @param options Request options.
  */
    async addWatcher(options) {
        const { headers, errorStrategy, contentId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a user as a watcher from a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-delete
  * @param options Request options.
  */
    async removeWatcher(options) {
        const { headers, errorStrategy, contentId, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1WatcherLabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether a user is watching a label. Choose the user by doing one
  of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-get
  * @param options Request options.
  */
    async getWatcherStatus(options) {
        const { headers, errorStrategy, labelName, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/watch/label/${encodeURIComponent(labelName)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user as a watcher to a label. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-post
  * @param options Request options.
  */
    async addWatcher(options) {
        const { headers, errorStrategy, labelName, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/user/watch/label/${encodeURIComponent(labelName)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a user as a watcher from a label. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-delete
  * @param options Request options.
  */
    async removeWatcher(options) {
        const { headers, errorStrategy, labelName, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/user/watch/label/${encodeURIComponent(labelName)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1WatcherSpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether a user is watching a space. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-get
  * @param options Request options.
  */
    async getWatcherStatus(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/watch/space/${encodeURIComponent(spaceKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user as a watcher to a space. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-post
  * @param options Request options.
  */
    async addWatcher(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/user/watch/space/${encodeURIComponent(spaceKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a user as a watcher from a space. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-delete
  * @param options Request options.
  */
    async removeWatcher(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/user/watch/space/${encodeURIComponent(spaceKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1UserGroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Member = new V1UserGroupMemberGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all user groups. The returned groups are ordered alphabetically in
  ascending order by group name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-get
  * @param options Request options.
  */
    async getUserGroups(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/group`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-post
  * @param options Request options.
  */
    async createUserGroup(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/group`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-delete
  * @param options Request options.
  */
    async deleteUserGroupById(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/group/by-id`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a user group for a given group id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-get
  * @param options Request options.
  */
    async getUserGroupById(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/group/by-id`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1UserGroupMemberGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Adds a user as a member in a group represented by its groupId
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-post
  * @param options Request options.
  */
    async addMemberById(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/group/userByGroupId`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Remove user as a member from a group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-delete
  * @param options Request options.
  */
    async removeMemberById(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/group/userByGroupId`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the users that are members of a group.
  
  Use updated Get group API
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-groupid-membersbygroupid-get
  * @param options Request options.
  */
    async getMembersById(options) {
        const { headers, errorStrategy, groupId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/group/${encodeURIComponent(groupId)}/membersByGroupId`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1LabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns label information and a list of contents associated with the label.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission). Only contents
  that the user is permitted to view is returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-label-info/#api-wiki-rest-api-label-get
  * @param options Request options.
  */
    async getInfo(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/label`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1LongRunningTaskGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns information about all active long-running tasks (e.g. space export),
  such as how long each task has been running and the percentage of each task
  that has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-get
  * @param options Request options.
  */
    async getLongRunningTasks(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/longtask`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns information about an active long-running task (e.g. space export),
  such as how long it has been running and the percentage of the task that
  has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-id-get
  * @param options Request options.
  */
    async getLongRunningTask(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/rest/api/longtask/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1RelationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all content that the current user
  has an 'ignore' relationship with:
  `GET /wiki/rest/api/relation/ignore/from/user/current/to/content`
  Note, 'ignore' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-get
  * @param options Request options.
  */
    async findTargetEntitiesRelatedToSourceEntity(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find whether a particular type of relationship exists from a source
  entity to a target entity. Note, relationships are one way.
  
  For example, you can use this method to find whether the current user has
  selected a particular page as a favorite (i.e. 'save for later'):
  `GET /wiki/rest/api/relation/favourite/from/user/current/to/content/123`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-get
  * @param options Request options.
  */
    async findRelationshipFromSourceToTarget(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, targetKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a relationship between two entities (user, space, content). The
  'favourite' relationship is supported by default, but you can use this method
  to create any type of relationship between two entities.
  
  For example, the following method creates a 'sibling' relationship between
  two pieces of content:
  `PUT /wiki/rest/api/relation/sibling/from/content/123/to/content/456`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-put
  * @param options Request options.
  */
    async createRelationship(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, targetKey, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a relationship between two entities (user, space, content).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  For favourite relationships, the current user can only delete their own
  favourite relationships. A space administrator can delete favourite
  relationships for any user.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-delete
  * @param options Request options.
  */
    async deleteRelationship(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, targetKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all users that have a 'collaborator'
  relationship to a piece of content with an ID of '1234':
  `GET /wiki/rest/api/relation/collaborator/to/content/1234/from/user`
  Note, 'collaborator' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-to-targettype-targetkey-from-sourcetype-get
  * @param options Request options.
  */
    async findSourceEntitiesRelatedToTargetEntity(options) {
        const { headers, errorStrategy, relationName, sourceType, targetType, targetKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}/from/${encodeURIComponent(sourceType)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1SearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Searches for content using the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  **Note that CQL input queries submitted through the `/wiki/rest/api/search` endpoint no longer support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.**
  See this [deprecation notice](https://developer.atlassian.com/cloud/confluence/deprecation-notice-search-api/) for more details.
  
  Example initial call:
  ```
  /wiki/rest/api/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the entities. Note, only entities that the user has
  permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-get
  * @param options Request options.
  */
    async searchContent(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Searches for users using user-specific queries from the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Note that CQL input queries submitted through the `/wiki/rest/api/search/user` endpoint only support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.
  
  Note that some user fields may be set to null depending on the user's privacy settings.
  These are: email, profilePicture, displayName, and timeZone.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-user-get
  * @param options Request options.
  */
    async searchUsers(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/search/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1SettingGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the look and feel settings for the site or a single space. This
  includes attributes such as the color scheme, padding, and border radius.
  
  The look and feel settings for a space can be inherited from the global
  look and feel settings or provided by a theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-get
  * @param options Request options.
  */
    async getLookAndFeelSettings(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/settings/lookandfeel`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the look and feel settings for the site or for a single space.
  If custom settings exist, they are updated. If no custom settings exist,
  then a set of custom settings is created.
  
  Note, if a theme is selected for a space, the space look and feel settings
  are provided by the theme and cannot be overridden.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-post
  * @param options Request options.
  */
    async updateLookAndFeelSettings(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/settings/lookandfeel/custom`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Resets the custom look and feel settings for the site or a single space.
  This changes the values of the custom settings to be the same as the
  default settings. It does not change which settings (default or custom)
  are selected. Note, the default space settings are inherited from the
  current global settings.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-delete
  * @param options Request options.
  */
    async resetLookAndFeelSettings(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/settings/lookandfeel/custom`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the system information for the Confluence Cloud tenant. This
  information is used by Atlassian.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-systeminfo-get
  * @param options Request options.
  */
    async getSystemInfo(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/wiki/rest/api/settings/systemInfo`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1SpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Private = new V1SpacePrivateGroup(implementation, this.getGlobalErrorStrategy);
        this.Setting = new V1SpaceSettingGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates a new space. Note, currently you cannot set space labels when
  creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-post
  * @param options Request options.
  */
    async createSpace(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/space`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the name, description, or homepage of a space.
  
  -   For security reasons, permissions cannot be updated via the API and
  must be changed via the user interface instead.
  -   Currently you cannot set space labels when updating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-put
  * @param options Request options.
  */
    async updateSpace(options) {
        const { body, headers, errorStrategy, spaceKey } = options;
        const request = new Request("PUT", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Permanently deletes a space without sending it to the trash. Note, the space will be deleted in a long running task.
  Therefore, the space may not be deleted yet when this method has
  returned. Clients should poll the status link that is returned in the
  response until the task completes.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-delete
  * @param options Request options.
  */
    async deleteSpace(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("DELETE", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1SpacePrivateGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a new space that is only visible to the creator. This method is
  the same as the [Create space](#api-space-post) method with permissions
  set to the current user only. Note, currently you cannot set space
  labels when creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-private-post
  * @param options Request options.
  */
    async createSpace(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/space/_private`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1SpaceSettingGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the settings of a space. Currently only the
  `routeOverrideEnabled` setting can be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-get
  * @param options Request options.
  */
    async getSettings(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("GET", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/settings`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the settings for a space. Currently only the
  `routeOverrideEnabled` setting can be updated.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-put
  * @param options Request options.
  */
    async updateSettings(options) {
        const { body, headers, errorStrategy, spaceKey } = options;
        const request = new Request("PUT", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/settings`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class V1TemplateGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Updates a content template. Note, blueprint templates cannot be updated
  via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to update a space template or 'Confluence Administrator'
  global permission to update a global template.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-put
  * @param options Request options.
  */
    async updateContentTemplate(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/wiki/rest/api/template`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content template. Note, blueprint templates cannot be created via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to create a space template or 'Confluence Administrator'
  global permission to create a global template.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-post
  * @param options Request options.
  */
    async createContentTemplate(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/template`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all templates provided by blueprints. Use this method to retrieve
  all global blueprint templates or all blueprint templates in a space.
  
  Note, all global blueprints are inherited by each space. Space blueprints
  can be customised without affecting the global blueprints.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view blueprints for the space and permission
  to access the Confluence site ('Can use' global permission) to view global blueprints.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-blueprint-get
  * @param options Request options.
  */
    async getBlueprintTemplates(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/template/blueprint`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all content templates. Use this method to retrieve all global
  content templates or all content templates in a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-page-get
  * @param options Request options.
  */
    async getContentTemplates(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/template/page`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a content template. This includes information about template,
  like the name, the space or blueprint that the template is in, the body
  of the template, and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-get
  * @param options Request options.
  */
    async getContentTemplate(options) {
        const { headers, errorStrategy, contentTemplateId } = options;
        const request = new Request("GET", `/wiki/rest/api/template/${encodeURIComponent(contentTemplateId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a template. This results in different actions depending on the
  type of template:
  
  - If the template is a content template, it is deleted.
  - If the template is a modified space-level blueprint template, it reverts
  to the template inherited from the global-level blueprint template.
  - If the template is a modified global-level blueprint template, it reverts
  to the default global-level blueprint template.
  
   Note, unmodified blueprint templates cannot be deleted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
          'Admin' permission for the space to delete a space template or 'Confluence Administrator'
          global permission to delete a global template.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-delete
  * @param options Request options.
  */
    async removeTemplate(options) {
        const { headers, errorStrategy, contentTemplateId } = options;
        const request = new Request("DELETE", `/wiki/rest/api/template/${encodeURIComponent(contentTemplateId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1ThemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all themes, not including the default theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-get
  * @param options Request options.
  */
    async getThemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/settings/theme`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the globally assigned theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-selected-get
  * @param options Request options.
  */
    async getGlobalTheme(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/wiki/rest/api/settings/theme/selected`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a theme. This includes information about the theme name,
  description, and icon.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-themekey-get
  * @param options Request options.
  */
    async getTheme(options) {
        const { headers, errorStrategy, themeKey } = options;
        const request = new Request("GET", `/wiki/rest/api/settings/theme/${encodeURIComponent(themeKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the theme selected for a space, if one is set. If no space
  theme is set, this means that the space is inheriting the global look
  and feel settings.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-get
  * @param options Request options.
  */
    async getSpaceTheme(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("GET", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/theme`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the theme for a space. Note, if you want to reset the space theme to
  the default Confluence theme, use the 'Reset space theme' method instead
  of this method.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-put
  * @param options Request options.
  */
    async setSpaceTheme(options) {
        const { body, headers, errorStrategy, spaceKey } = options;
        const request = new Request("PUT", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/theme`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Resets the space theme. This means that the space will inherit the
  global look and feel settings
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-delete
  * @param options Request options.
  */
    async resetSpaceTheme(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("DELETE", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/theme`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class V1UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a user. This includes information about the user, such as the
  display name, account ID, profile picture, and more. The information returned may be
  restricted by the user's profile visibility settings.
  
  **Note:** to add, edit, or delete users in your organization, see the
  [user management REST API](/cloud/admin/user-management/about/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-group-users
  * @param options Request options.
  */
    async getUser(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns information about how anonymous users are represented, like the
  profile picture and display name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-anonymous-get
  * @param options Request options.
  */
    async getAnonymousUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/anonymous`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the currently logged-in user. This includes information about
  the user, like the display name, userKey, account ID, profile picture,
  and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-current-get
  * @param options Request options.
  */
    async getCurrentUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/current`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the groups that a user is a member of.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-memberof-get
  * @param options Request options.
  */
    async getGroupsWhereUserMember(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/memberof`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns user details for the ids provided in the request.
  Currently this API returns a maximum of 100 results.
  If more than 100 account ids are passed in, then the first 100 will be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-bulk-get
  * @param options Request options.
  */
    async getUsersWithIds(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/bulk`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a user's email address regardless of the user's profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-get
  * @param options Request options.
  */
    async getUserEmail(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/email`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a user's email address regardless of the user’s profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  Any accounts which are not available will not be included in the result.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-bulk-get
  * @param options Request options.
  */
    async getUserEmails(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/email/bulk`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map